@@ -35,6 +35,7 @@
 #include <PlotCurve.h>
 #include <MultiLayer.h>
 #include <ColorBox.h>
+#include <Matrix.h>
 
 #include <QApplication>
 #include <QMessageBox>
@@ -67,6 +68,14 @@ Filter::Filter( ApplicationWindow *parent, Table *t, const QString& name)
 	d_table = t;
 }
 
+Filter::Filter( ApplicationWindow *parent, Matrix *m, const QString& name)
+: QObject(parent)
+{
+	init();
+	setObjectName(name);
+	d_matrix = m;
+}
+
 void Filter::init()
 {
 	d_n = 0;
@@ -87,6 +96,7 @@ void Filter::init()
 	d_graphics_display = true;
 	d_update_output_graph = true;
 	d_y_col_name = QString::null;
+	d_matrix = NULL;
 }
 
 void Filter::setInterval(double from, double to)
@@ -258,6 +268,11 @@ void Filter::showLegend()
 
 bool Filter::run()
 {
+	if (d_matrix){
+		output();
+		return true;
+	}
+
 	if (d_init_err)
 		return false;
 
@@ -492,7 +507,7 @@ MultiLayer * Filter::createOutputGraph()
 	return ml;
 }
 
-bool Filter::setDataFromTable(Table *t, const QString& xColName, const QString& yColName, int startRow, int endRow)
+bool Filter::setDataFromTable(Table *t, const QString& xColName, const QString& yColName, int startRow, int endRow, bool sort)
 {
 	d_init_err = true;
 
@@ -520,7 +535,7 @@ bool Filter::setDataFromTable(Table *t, const QString& xColName, const QString&
     QVector<double> X(r), Y(r);
 
 	int size = 0;
-	for (int i = from; i<=to; i++ ){
+	for (int i = from; i <= to; i++){
 		QString xval = t->text(i, xcol);
 		QString yval = t->text(i, ycol);
 		if (!xval.isEmpty() && !yval.isEmpty()){
@@ -534,7 +549,7 @@ bool Filter::setDataFromTable(Table *t, const QString& xColName, const QString&
 
 	if (size < d_min_points){
 		QMessageBox::critical((ApplicationWindow *)parent(), tr("QtiPlot") + " - " + tr("Error"),
-				tr("You need at least %1 points in order to perform this operation!").arg(d_min_points));
+		tr("You need at least %1 points in order to perform this operation!").arg(d_min_points));
         return false;
 	}
 
@@ -551,6 +566,7 @@ bool Filter::setDataFromTable(Table *t, const QString& xColName, const QString&
 	Y.resize(d_n);
 	d_from = X[0];
     d_to = X[d_n-1];
+	d_sort_data = sort;
 
 	d_x = (double *)malloc(d_n*sizeof(double));
 	if (!d_x){
