@@ -37,6 +37,7 @@ class MultiLayer;
 class QwtPlotCurve;
 class Graph;
 class Table;
+class Matrix;
 
 //! Abstract base class for data analysis operations
 class Filter : public QObject
@@ -46,6 +47,7 @@ class Filter : public QObject
 	public:
         Filter(ApplicationWindow *parent, Table *t = 0, const QString& name = QString());
 		Filter(ApplicationWindow *parent, Graph *g = 0, const QString& name = QString());
+		Filter(ApplicationWindow *parent, Matrix *m, const QString& name = QString());
 		Filter(ApplicationWindow *parent, QwtPlotCurve *c);
 		~Filter();
 
@@ -58,7 +60,7 @@ class Filter : public QObject
 		bool setDataFromCurve(const QString& curveTitle, Graph *g = 0);
 		bool setDataFromCurve(const QString& curveTitle, double from, double to, Graph *g = 0);
 
-		virtual bool setDataFromTable(Table *, const QString&, const QString&, int = 1, int = -1);
+		virtual bool setDataFromTable(Table *, const QString&, const QString&, int = 1, int = -1, bool = false);
 
 		//! Changes the data range if the source curve was already assigned. Provided for convenience.
 		void setInterval(double from, double to);
@@ -82,6 +84,8 @@ class Filter : public QObject
 		//! Sets the maximum number of iterations to be performed during an iterative session
 		void setMaximumIterations(int iter){d_max_iterations = iter;};
 
+		void setSortData(bool on = true){d_sort_data = on;}
+
 		//! Adds a new legend to the plot. Calls virtual legendInfo()
 		virtual void showLegend();
 
@@ -198,6 +202,7 @@ class Filter : public QObject
 		bool d_update_output_graph;
 
 		QString d_y_col_name;
+		Matrix *d_matrix;
 };
 
 #endif
