@@ -2,7 +2,7 @@
     File                 : ApplicationWindow.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-	Copyright            : (C) 2004 - 2010 by Ion Vasilief,
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief,
 						   (C) 2006 - june 2007 Tilman Hoener zu Siederdissen, Knut Franke
 	Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : QtiPlot's main window
@@ -46,8 +46,7 @@
 #include <ScriptingEnv.h>
 #include <Script.h>
 #include <TranslateCurveTool.h>
-
-#include <qwt_color_map.h>
+#include <LinearColorMap.h>
 
 #ifdef BROWSER_PLUGIN
 #include <qtbrowserplugin.h>
@@ -160,6 +159,7 @@ public:
 	enum EndLineChar{LF, CRLF, CR};
 	enum Analysis{NoAnalysis, Integrate, Diff, FitLinear, FitGauss, FitLorentz, FitSigmoidal, FitSlope};
 	enum LaTeXCompiler{MathTran, Local};
+	enum ExcelImportMethod{ExcelFormatLibrary, LocalOpenOffice, LocalExcelInstallation};
 
 	FolderListView *lv, *folders;
 	QDockWidget *logWindow;
@@ -245,6 +245,15 @@ public:
 	//@}
 
 	bool isFileReadable(const QString&);
+#ifdef Q_OS_WIN
+	bool importUsingExcel();
+	bool isExcelInstalled(){return d_has_excel;};
+#endif
+
+	ExcelImportMethod excelImportMethod(){return d_excel_import_method;};
+	void setExcelImportMethod(const ExcelImportMethod& method){d_excel_import_method = method;};
+
+	void showNoDataMessage();
 
 public slots:
 	//! \name Projects and Project Files
@@ -310,7 +319,7 @@ public slots:
 	//! \name Multilayer Plots
 	//@{
 	//! Creates a new empty multilayer plot
-	MultiLayer* newGraph(const QString& caption = tr("Graph"));
+	MultiLayer* newGraph(const QString& caption = tr("Graph") + "1");
 	MultiLayer* multilayerPlot(int c, int r, int style, const MultiLayer::AlignPolicy& align = MultiLayer::AlignLayers);
 	MultiLayer* multilayerPlot(Table* w, const QStringList& colList, int style, int startRow = 0, int endRow = -1);
 	//! used when restoring a plot from a project file
@@ -335,7 +344,7 @@ public slots:
 
 	//! Rearrange the layersin order to fit to the size of the plot window
   	void autoArrangeLayers();
-	void initMultilayerPlot(MultiLayer* g, const QString& name);
+	void initMultilayerPlot(MultiLayer* g, const QString& name = QString());
 	void plot2VerticalLayers();
 	void plot2HorizontalLayers();
 	void plot4Layers();
@@ -480,12 +489,7 @@ public slots:
 	void initTable(Table* w, const QString& caption);
 	void customTable(Table* w);
 	Table* importOdfSpreadsheet(const QString& = QString::null, int sheet = -1);
-
 	Table* importExcel(const QString& = QString::null, int sheet = -1);
-#ifdef Q_OS_WIN
-	bool isExcelInstalled(){return d_has_excel;};
-#endif
-
 	void exportExcel();
 	void exportOds();
 
@@ -691,6 +695,10 @@ public slots:
 	void graphSelectionChanged(SelectionMoveResizer *);
 	void lowerActiveEnrichment();
 	void raiseActiveEnrichment(bool = true);
+	void alignTop();
+	void alignBottom();
+	void alignLeft();
+	void alignRight();
 	void newLegend();
 	void addTimeStamp();
 	void drawLine();
@@ -807,7 +815,7 @@ public slots:
 	void showPlotWizard();
 	void showFitPolynomDialog();
     void showFrequencyCountDialog();
-	void showIntegrationDialog();
+	void showFunctionIntegrationDialog();
 	void showInterpolationDialog();
 	void showExpGrowthDialog();
 	void showExpDecayDialog();
@@ -939,8 +947,8 @@ public slots:
 	bool alreadyUsedName(const QString& label);
 	bool projectHas2DPlots();
 
-	//! Returns a pointer to the window named "name"
-	MdiSubWindow* window(const QString& name);
+	//! Returns a pointer to the window named/labelled "name" depending on "label" value
+	MdiSubWindow* window(const QString& name, bool label = false);
 
 	//! Returns a list with the names of all the matrices in the project
 	QStringList matrixNames();
@@ -1187,6 +1195,13 @@ private slots:
 
 // TODO: a lot of this stuff should be private
 public:
+	bool d_fft_norm_amp;
+	bool d_fft_shift_res;
+	bool d_fft_power2;
+	bool d_int_sort_data;
+	bool d_int_show_plot;
+	bool d_int_results_table;
+	bool d_show_empty_cell_gap;
 	bool d_show_table_paste_dialog;
 	double d_stats_significance_level;
 	bool d_stats_result_table;
@@ -1208,6 +1223,7 @@ public:
 	bool d_muparser_c_locale;
 	Graph::LegendDisplayMode d_graph_legend_display;
 	Graph::AxisTitlePolicy d_graph_axis_labeling;
+	int d_graph_attach_policy;
 	bool d_synchronize_graph_scales;
 	int d_latex_compiler;
 	QString d_latex_compiler_path;
@@ -1253,7 +1269,7 @@ public:
     QString d_image_export_filter, d_export_ASCII_file_filter;
     double d_scale_fonts_factor;
     bool d_export_transparency;
-    int d_export_quality;
+	int d_export_quality, d_export_compression;
     int d_export_vector_resolution, d_export_bitmap_resolution, d_export_size_unit;
     QSizeF d_export_raster_size;
     bool d_export_color;
@@ -1393,7 +1409,7 @@ public:
 	bool d_3D_smooth_mesh, d_3D_legend, d_3D_orthogonal, d_3D_autoscale;
 	int d_3D_resolution, d_3D_projection;
 	QFont d_3D_title_font, d_3D_numbers_font, d_3D_axes_font;
-	QwtLinearColorMap d_3D_color_map;
+	LinearColorMap d_3D_color_map;
 	QColor d_3D_mesh_color;
 	QColor d_3D_axes_color;
 	QColor d_3D_numbers_color;
@@ -1408,18 +1424,15 @@ public:
 	//@}
 
 private:
-#ifdef Q_OS_WIN
-	void detectExcel();
-#endif
 	void loadPlugins();
 	QList<ImportExportPlugin *> d_import_export_plugins;
 
 	bool d_mdi_windows_area;
 	MdiSubWindow *d_active_window;
-    TextEditor *d_text_editor;
+	TextEditor *d_text_editor;
 	// Flag telling if table values should be automatically recalculated when values in a column are modified.
 	bool d_auto_update_table_values;
-    int d_matrix_undo_stack_size;
+	int d_matrix_undo_stack_size;
 
 	//! Workaround for the new colors introduced in rev 447
 	int convertOldToNewColorIndex(int cindex);
@@ -1446,7 +1459,7 @@ private:
 #endif
 	QMdiArea *d_workspace;
 
-    QToolBar *fileTools, *plotTools, *tableTools, *columnTools, *plot3DTools, *displayBar, *editTools, *plotMatrixBar;
+	QToolBar *fileTools, *plotTools, *tableTools, *columnTools, *plot3DTools, *displayBar, *editTools, *plotMatrixBar;
 	QToolBar *formatToolBar, *noteTools;
 	QToolButton *btnResults;
 	QWidgetList *hiddenWindows;
@@ -1461,51 +1474,51 @@ private:
 
 	QAction *actionEditCurveRange, *actionCurveFullRange, *actionShowAllCurves, *actionHideCurve, *actionHideOtherCurves;
 	QAction *actionRemoveCurve, *actionShowCurveWorksheet, *actionShowCurvePlotDialog;
-    QAction *actionNewProject, *actionAppendProject, *actionNewNote, *actionNewTable, *actionNewFunctionPlot;
-    QAction *actionNewSurfacePlot, *actionNewMatrix, *actionNewGraph, *actionNewFolder;
-    QAction *actionOpen, *actionLoadImage, *actionSaveProject, *actionSaveProjectAs, *actionImportImage;
+	QAction *actionNewProject, *actionAppendProject, *actionNewNote, *actionNewTable, *actionNewFunctionPlot;
+	QAction *actionNewSurfacePlot, *actionNewMatrix, *actionNewGraph, *actionNewFolder;
+	QAction *actionOpen, *actionLoadImage, *actionSaveProject, *actionSaveProjectAs, *actionImportImage;
 	QAction *actionLoad, *actionUndo, *actionRedo, *actionImportSound;
 	QAction *actionImportDatabase, *actionOpenOds;
 	QAction *actionExportExcel, *actionExportOds, *actionOpenExcel;
-    QAction *actionCopyWindow, *actionShowAllColumns, *actionHideSelectedColumns;
-    QAction *actionCutSelection, *actionCopySelection, *actionPasteSelection, *actionClearSelection;
-    QAction *actionShowExplorer, *actionShowLog, *actionAddLayer, *actionShowLayerDialog, *actionAutomaticLayout;
+	QAction *actionCopyWindow, *actionShowAllColumns, *actionHideSelectedColumns;
+	QAction *actionCutSelection, *actionCopySelection, *actionPasteSelection, *actionClearSelection;
+	QAction *actionShowExplorer, *actionShowLog, *actionAddLayer, *actionShowLayerDialog, *actionAutomaticLayout;
 #ifdef SCRIPTING_CONSOLE
-    QAction *actionShowConsole;
+	QAction *actionShowConsole;
 #endif
 #ifdef SCRIPTING_PYTHON
 	QAction *actionOpenQtDesignerUi, *actionCommentSelection, *actionUncommentSelection;
 #endif
-    QAction *actionSwapColumns, *actionMoveColRight, *actionMoveColLeft, *actionMoveColFirst, *actionMoveColLast, *actionShowScriptWindow;
-    QAction *actionExportGraph, *actionExportAllGraphs, *actionPrint, *actionPrintAllPlots, *actionShowExportASCIIDialog;
-    QAction *actionExportPDF, *actionReadOnlyCol, *actionStemPlot;
-    QAction *actionCloseAllWindows, *actionCloseProject, *actionClearLogInfo, *actionShowPlotWizard, *actionShowConfigureDialog;
-    QAction *actionShowCurvesDialog, *actionAddErrorBars, *actionAddFunctionCurve, *actionUnzoom, *actionNewLegend, *actionAddImage, *actionAddText;
-    QAction *actionPlotL, *actionPlotP, *actionPlotLP, *actionPlotVerticalDropLines, *actionPlotSpline;
-    QAction *actionPlotVertSteps, *actionPlotHorSteps, *actionPlotVerticalBars, *actionStackBars, *actionStackColumns;
+	QAction *actionSwapColumns, *actionMoveColRight, *actionMoveColLeft, *actionMoveColFirst, *actionMoveColLast, *actionShowScriptWindow;
+	QAction *actionExportGraph, *actionExportAllGraphs, *actionPrint, *actionPrintAllPlots, *actionShowExportASCIIDialog;
+	QAction *actionExportPDF, *actionReadOnlyCol, *actionStemPlot;
+	QAction *actionCloseAllWindows, *actionCloseProject, *actionClearLogInfo, *actionShowPlotWizard, *actionShowConfigureDialog;
+	QAction *actionShowCurvesDialog, *actionAddErrorBars, *actionAddFunctionCurve, *actionUnzoom, *actionNewLegend, *actionAddImage, *actionAddText;
+	QAction *actionPlotL, *actionPlotP, *actionPlotLP, *actionPlotVerticalDropLines, *actionPlotSpline;
+	QAction *actionPlotVertSteps, *actionPlotHorSteps, *actionPlotVerticalBars, *actionStackBars, *actionStackColumns;
 	QAction *actionPlotHorizontalBars, *actionPlotArea, *actionPlotPie, *actionPlotVectXYAM, *actionPlotVectXYXY;
-    QAction *actionPlotHistogram, *actionPlotStackedHistograms, *actionPlot2VerticalLayers, *actionPlot2HorizontalLayers, *actionPlot4Layers, *actionPlotStackedLayers;
-    QAction *actionPlot3DRibbon, *actionPlot3DBars, *actionPlot3DScatter, *actionPlot3DTrajectory;
-    QAction *actionPlotDoubleYAxis, *actionAddInsetLayer, *actionAddInsetCurveLayer;
-    QAction *actionShowColStatistics, *actionShowRowStatistics, *actionShowIntDialog, *actionIntegrate;
-    QAction *actionDifferentiate, *actionFitLinear, *actionFitSlope, *actionShowFitPolynomDialog;
-    QAction *actionShowExpDecayDialog, *actionShowTwoExpDecayDialog, *actionShowExpDecay3Dialog;
-    QAction *actionFitExpGrowth, *actionFitSigmoidal, *actionFitGauss, *actionFitLorentz, *actionShowFitDialog;
-    QAction *actionShowAxisDialog, *actionShowTitleDialog;
-    QAction *actionShowColumnOptionsDialog, *actionShowColumnValuesDialog, *actionShowColsDialog, *actionShowRowsDialog;
-    QAction *actionTableRecalculate, *actionExtractGraphs, *actionExtractLayers;
-    QAction *actionAbout, *actionShowHelp, *actionChooseHelpFolder;
-    QAction *actionRename, *actionCloseWindow;
+	QAction *actionPlotHistogram, *actionPlotStackedHistograms, *actionPlot2VerticalLayers, *actionPlot2HorizontalLayers, *actionPlot4Layers, *actionPlotStackedLayers;
+	QAction *actionPlot3DRibbon, *actionPlot3DBars, *actionPlot3DScatter, *actionPlot3DTrajectory;
+	QAction *actionPlotDoubleYAxis, *actionAddInsetLayer, *actionAddInsetCurveLayer;
+	QAction *actionShowColStatistics, *actionShowRowStatistics, *actionShowIntDialog, *actionIntegrate;
+	QAction *actionDifferentiate, *actionFitLinear, *actionFitSlope, *actionShowFitPolynomDialog;
+	QAction *actionShowExpDecayDialog, *actionShowTwoExpDecayDialog, *actionShowExpDecay3Dialog;
+	QAction *actionFitExpGrowth, *actionFitSigmoidal, *actionFitGauss, *actionFitLorentz, *actionShowFitDialog;
+	QAction *actionShowAxisDialog, *actionShowTitleDialog;
+	QAction *actionShowColumnOptionsDialog, *actionShowColumnValuesDialog, *actionShowColsDialog, *actionShowRowsDialog;
+	QAction *actionTableRecalculate, *actionExtractGraphs, *actionExtractLayers;
+	QAction *actionAbout, *actionShowHelp, *actionChooseHelpFolder;
+	QAction *actionRename, *actionCloseWindow;
 	QAction *actionConvertTableDirect, *actionConvertTableBinning, *actionConvertTableRegularXYZ;
 #ifdef HAVE_ALGLIB
 	QAction *actionConvertTableRandomXYZ, *actionExpandMatrix, *actionShrinkMatrix, *actionSmoothMatrix;
 #endif
-    QAction *actionAddColToTable, *actionDeleteLayer, *actionInterpolate;
-    QAction *actionResizeActiveWindow, *actionHideActiveWindow;
-    QAction *actionShowMoreWindows, *actionPixelLineProfile, *actionIntensityTable;
-    QAction *actionShowLineDialog, *actionShowTextDialog;
-    QAction *actionActivateWindow, *actionMinimizeWindow, *actionMaximizeWindow, *actionHideWindow, *actionResizeWindow;
-    QAction *actionEditSurfacePlot, *actionAdd3DData;
+	QAction *actionAddColToTable, *actionDeleteLayer, *actionInterpolate;
+	QAction *actionResizeActiveWindow, *actionHideActiveWindow;
+	QAction *actionShowMoreWindows, *actionPixelLineProfile, *actionIntensityTable;
+	QAction *actionShowLineDialog, *actionShowTextDialog;
+	QAction *actionActivateWindow, *actionMinimizeWindow, *actionMaximizeWindow, *actionHideWindow, *actionResizeWindow;
+	QAction *actionEditSurfacePlot, *actionAdd3DData;
 	QAction *actionMatrixDeterminant, *actionSetMatrixProperties, *actionConvertMatrixXYZ, *actionConvertMatrixYXZ;
 	QAction *actionSetMatrixDimensions, *actionConvertMatrixDirect, *actionSetMatrixValues, *actionTransposeMatrix, *actionInvertMatrix;
 	QAction *actionPlot3DWireFrame, *actionPlot3DHiddenLine, *actionPlot3DPolygons, *actionPlot3DWireSurface;
@@ -1526,37 +1539,38 @@ private:
 	QAction *actionNoteExecute, *actionNoteExecuteAll, *actionNoteEvaluate, *actionSaveNote, *actionFrequencyCount;
 	QAction *actionOneSampletTest, *actionTwoSampletTest, *actionShapiroWilk, *actionChiSquareTest;
 	QAction *actionAnimate, *actionPerspective, *actionFitFrame, *actionResetRotation;
-    QAction *actionDeleteRows, *actionDrawPoints, *actionAddZoomPlot;
+	QAction *actionDeleteRows, *actionDrawPoints, *actionAddZoomPlot;
 	QAction *btnCursor, *btnSelect, *btnPicker, *btnRemovePoints, *btnMovePoints, *actionDragCurve;
 	QAction *btnZoomIn, *btnZoomOut, *btnPointer, *btnLine, *btnArrow;
 	QAction *actionFlipMatrixVertically, *actionFlipMatrixHorizontally, *actionRotateMatrix;
 	QAction *actionViewMatrixImage, *actionViewMatrix, *actionExportMatrix, *actionMatrixDefaultScale;
-    QAction *actionMatrixGrayScale, *actionMatrixRainbowScale, *actionMatrixCustomScale, *actionRotateMatrixMinus;
-    QAction *actionMatrixXY, *actionMatrixColumnRow, *actionImagePlot, *actionToolBars, *actionImageProfilesPlot;
-    QAction *actionMatrixFFTDirect, *actionMatrixFFTInverse;
+	QAction *actionMatrixGrayScale, *actionMatrixRainbowScale, *actionMatrixCustomScale, *actionRotateMatrixMinus;
+	QAction *actionMatrixXY, *actionMatrixColumnRow, *actionImagePlot, *actionToolBars, *actionImageProfilesPlot;
+	QAction *actionMatrixFFTDirect, *actionMatrixFFTInverse;
 	QAction *actionFontBold, *actionFontItalic, *actionFontBox, *actionFontSize, *actionTextColor;
 	QAction *actionSuperscript, *actionSubscript, *actionUnderline, *actionGreekSymbol, *actionCustomActionDialog;
 	QAction *actionGreekMajSymbol, *actionMathSymbol;
 	QAction *Box, *Frame, *None;
-    QAction *front, *back, *right, *left, *ceil, *floor, *floordata, *flooriso, *floornone;
-    QAction *wireframe, *hiddenline, *polygon, *filledmesh, *pointstyle, *barstyle, *conestyle, *crossHairStyle;
-    QAction *actionShowUndoStack, *actionShowNoteLineNumbers, *actionAddFormula, *actionAddRectangle, *actionAddEllipse;
-    QActionGroup *coord, *floorstyle, *grids, *plotstyle, *dataTools;
+	QAction *front, *back, *right, *left, *ceil, *floor, *floordata, *flooriso, *floornone;
+	QAction *wireframe, *hiddenline, *polygon, *filledmesh, *pointstyle, *barstyle, *conestyle, *crossHairStyle;
+	QAction *actionShowUndoStack, *actionShowNoteLineNumbers, *actionAddFormula, *actionAddRectangle, *actionAddEllipse;
+	QActionGroup *coord, *floorstyle, *grids, *plotstyle, *dataTools;
 	QAction *actionMagnify, *actionFindWindow, *actionWaterfallPlot, *actionMagnifyHor, *actionMagnifyVert;
-    QAction *actionMoveRowUp, *actionMoveRowDown, *actionAdjustColumnWidth;
+	QAction *actionMoveRowUp, *actionMoveRowDown, *actionAdjustColumnWidth;
 #if QT_VERSION >= 0x040500
 	QAction *actionPresentationODF;
 #endif
 	QAction *actionRenameNoteTab, *actionAddNoteTab, *actionCloseNoteTab;
-    QAction *actionIncreaseIndent, *actionDecreaseIndent, *actionFind, *actionFindNext, *actionFindPrev, *actionReplace;
-    QAction *actionIncreasePrecision, *actionDecreasePrecision, *actionPrintPreview;
+	QAction *actionIncreaseIndent, *actionDecreaseIndent, *actionFind, *actionFindNext, *actionFindPrev, *actionReplace;
+	QAction *actionIncreasePrecision, *actionDecreasePrecision, *actionPrintPreview;
 	QAction *actionVertSharedAxisLayers, *actionHorSharedAxisLayers, *actionSharedAxesLayers, *actionStackSharedAxisLayers;
 	QAction *actionCustomSharedAxisLayers, *actionCustomLayout, *actionExtractTableData, *actionSubtractLine, *actionSubtractReference;
 	QAction *actionRaiseEnrichment, *actionLowerEnrichment, *actionBaseline;
+	QAction *actionAlignTop, *actionAlignBottom, *actionAlignLeft, *actionAlignRight;
 
-    QList<QAction *> d_user_actions;
-    QUndoView *d_undo_view;
-    QList<QMenu *> d_user_menus;
+	QList<QAction *> d_user_actions;
+	QUndoView *d_undo_view;
+	QList<QMenu *> d_user_menus;
 
 	QList<QColor> d_indexed_colors;
 	QStringList d_indexed_color_names;
@@ -1565,7 +1579,9 @@ private:
 	QAction *actionOneWayANOVA, *actionTwoWayANOVA;
 #endif
 #ifdef Q_OS_WIN
+	void detectExcel();
 	bool d_has_excel;
 #endif
+	ExcelImportMethod d_excel_import_method;
 };
 #endif
