@@ -2,7 +2,7 @@
     File                 : ImportASCIIDialog.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-	Copyright            : (C) 2004 - 2010 by Ion Vasilief,
+	Copyright            : (C) 2004 - 2011 by Ion Vasilief,
 						   (C) 2006 - June 2007 by Knut Franke
 	Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Import ASCII file(s) dialog
@@ -60,6 +60,7 @@ ImportASCIIDialog::ImportASCIIDialog(bool new_windows_only, QWidget * parent, bo
 	initAdvancedOptions();
 	setNewWindowsOnly(new_windows_only);
 	setExtensionWidget(d_advanced_options);
+	setEditableFilter();
 
 	// get rembered option values
 	ApplicationWindow *app = (ApplicationWindow *)parent;
@@ -110,6 +111,7 @@ ImportASCIIDialog::ImportASCIIDialog(bool new_windows_only, QWidget * parent, bo
     connect(boxDecimalSeparator, SIGNAL(currentIndexChanged(int)), this, SLOT(preview()));
     connect(d_comment_string, SIGNAL(textChanged(const QString&)), this, SLOT(preview()));
     connect(this, SIGNAL(currentChanged(const QString&)), this, SLOT(changePreviewFile(const QString&)));
+	connect(this, SIGNAL(filterSelected(const QString &)), this, SLOT(selectFilter(const QString &)));
 }
 
 void ImportASCIIDialog::initAdvancedOptions()
@@ -158,7 +160,7 @@ void ImportASCIIDialog::initAdvancedOptions()
 	d_ignored_lines->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
 	advanced_layout->addWidget(d_ignored_lines, 2, 1);
 
-	advanced_layout->addWidget(new QLabel(tr("Ignore lines starting with")), 3, 0);
+	advanced_layout->addWidget(new QLabel(tr("Ignore lines containing")), 3, 0);
 	d_comment_string = new QLineEdit();
     advanced_layout->addWidget(d_comment_string, 3, 1);
 
@@ -568,10 +570,10 @@ void ImportASCIIDialog::selectFilter(const QString & filter)
 	if (!filters.contains(filter))
 		filters << filter;
 
-	setFilters(filters);
-	setEditableFilter();
-
-	QFileDialog::selectFilter(filter);
+	blockSignals(true);
+	setNameFilters(filters);
+	selectNameFilter(filter);
+	blockSignals(false);
 }
 
 /*****************************************************************************
@@ -715,13 +717,17 @@ void PreviewTable::importASCII(const QString &fname, const QString &sep, int ign
 
 	if ((!renameCols || allNumbers)&& !importComments && rows > 0){
 		//put values in the first line of the table
-		for (int i = 0; i<cols; i++){
+		for (int i = 0; i < cols; i++){
+			QString cell = line[i];
+			if (cell.isEmpty())
+				continue;
+
 			bool ok;
-			double val = importLocale.toDouble(line[i], &ok);
+			double val = importLocale.toDouble(cell, &ok);
 			if (colTypes[startCol + i] == Table::Numeric && (ok || updateDecimalSeparators))
 				setText(startRow, startCol + i, locale.toString(val, 'g', d_numeric_precision));
 			else
-				setText(startRow, startCol + i, line[i]);
+				setText(startRow, startCol + i, cell);
 		}
 		startRow++;
 	}
@@ -746,12 +752,16 @@ void PreviewTable::importASCII(const QString &fname, const QString &sep, int ign
 			cols = lc;
 		}
 		for (int j = 0; j < cols && j < lc; j++){
+			QString cell = line[j];
+			if (cell.isEmpty())
+				continue;
+
 			bool ok;
-			double val = importLocale.toDouble(line[j], &ok);
+			double val = importLocale.toDouble(cell, &ok);
 			if (colTypes[startCol + j] == Table::Numeric && (ok || updateDecimalSeparators))
 				setText(row, startCol + j, locale.toString(val, 'g', d_numeric_precision));
 			else
-				setText(row, startCol + j, line[j]);
+				setText(row, startCol + j, cell);
 		}
 
 		row++;
