@@ -2,7 +2,8 @@
     File                 : globals.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief, Tilman Hoener zu Siederdissen
+	Copyright            : (C) 2006 - 2011 by Ion Vasilief
+						   (C) 2006 by Tilman Hoener zu Siederdissen
     Email (use @ for *)  : ion_vasilief*yahoo.fr, thzs*gmx.net
     Description          : Definition of global constants
 
@@ -34,10 +35,10 @@ const int min_version = 9;
 //! Patch version number (0..9)
 const int patch_version = 8;
 //! Extra version information string (like "alpha", "-2", etc...)
-const char * extra_version = ".4";
-const char * svn_revision = SVN_REVISION;  //SRB: SVN_REVISION set by compiler from QTIPLOT_SVN_REVISION environment variable. (10/1/2010 )
+const char * extra_version = ".8";
+const char * svn_revision = " svn 2255";//SVN_REVISION;  //SRB: SVN_REVISION set by compiler from QTIPLOT_SVN_REVISION environment variable. (10/1/2010 )
 
 //! Copyright string containing the author names
 const char * copyright_string = "Copyright (C) 2004-2011 Ion Vasilief";
 //! Release date as a string
-const char * release_date = " 2011/02/17";
+const char * release_date = " 2011/09/02";
