@@ -32,7 +32,6 @@
 #include <ApplicationWindow.h>
 #include <muParserScript.h>
 #include <ScriptingEnv.h>
-#include <ColorMapEditor.h>
 #include <ExcelFileConverter.h>
 #include <ImportExportPlugin.h>
 
@@ -215,7 +214,7 @@ void Matrix::save(const QString &fn, const QString &info, bool saveAsTemplate)
 	if (d_color_map_type != Custom)
 		t << "ColorPolicy\t" + QString::number(d_color_map_type) + "\n";
 	else
-		t << ColorMapEditor::saveToXmlString(d_color_map);
+		t << d_color_map.toXmlString();
 
     if (notTemplate){//save data
 		t << "<data>\n";
@@ -291,26 +290,29 @@ void Matrix::restore(const QStringList &lst)
 	l = (*i++).split("\t");
 	d_color_map_type = (Matrix::ColorMapType)l[1].toInt();
 
-    if (lst.contains ("<ColorMap>")){
-        QStringList aux;
-        while (*i != "</ColorMap>"){
-            aux << *i;
-            i++;
-        }
-        setColorMap(aux);
-    }
+	if (lst.contains ("<ColorMap>")){
+		QStringList aux;
+		while (*i != "</ColorMap>"){
+			aux << *i;
+			i++;
+		}
+		setColorMap(LinearColorMap::fromXmlStringList(aux));
+	}
 
-    if (d_view_type == ImageView){
-	    if (d_table_view)
-            delete d_table_view;
-        if (d_select_all_shortcut)
-            delete d_select_all_shortcut;
-	    initImageView();
+	if (!formula_str.isEmpty())
+		calculate();
+
+	if (d_view_type == ImageView){
+		if (d_table_view)
+			delete d_table_view;
+		if (d_select_all_shortcut)
+			delete d_select_all_shortcut;
+		initImageView();
 		d_stack->setCurrentWidget(imageLabel);
 		if (d_color_map_type == Rainbow)
-            setRainbowColorMap();
+			setRainbowColorMap();
 	}
-    resetView();
+	resetView();
 }
 
 void Matrix::setNumericPrecision(int prec)
@@ -924,7 +926,7 @@ void Matrix::customEvent(QEvent *e)
 		scriptingChangeEvent((ScriptingChangeEvent*)e);
 }
 
-void Matrix::exportRasterImage(const QString& fileName, int quality, int dpi)
+void Matrix::exportRasterImage(const QString& fileName, int quality, int dpi, int compression)
 {
 	if (!dpi)
 		dpi = logicalDpiX();
@@ -946,7 +948,15 @@ void Matrix::exportRasterImage(const QString& fileName, int quality, int dpi)
 		writer.write(document);
 	} else
 #endif
-		image.save(fileName, 0, quality);
+	{
+		QImageWriter writer(fileName);
+		if (compression > 0 && writer.supportsOption(QImageIOHandler::CompressionRatio)){
+			writer.setQuality(quality);
+			writer.setCompression(compression);
+			writer.write(image);
+		} else
+			image.save(fileName, 0, quality);
+	}
 }
 
 void Matrix::exportToFile(const QString& fileName)
@@ -1109,38 +1119,46 @@ void Matrix::print(const QString& fileName)
 	print(&printer);
 }
 
+void Matrix::exportVector(QPrinter *printer, int res, bool color)
+{
+	if (!printer)
+		return;
+
+	printer->setCreator("QtiPlot");
+	printer->setFullPage(true);
+	if (res)
+		printer->setResolution(res);
+
+	if (color)
+		printer->setColorMode(QPrinter::Color);
+	else
+		printer->setColorMode(QPrinter::GrayScale);
+
+	printer->setOrientation(QPrinter::Portrait);
+
+	int cols = numCols();
+	int rows = numRows();
+	QRect rect = QRect(0, 0, cols, rows);
+	printer->setPaperSize(QSizeF(cols, rows), QPrinter::DevicePixel);
+
+	QPainter paint(printer);
+	paint.drawImage(rect, d_matrix_model->renderImage());
+	paint.end();
+}
+
 void Matrix::exportVector(const QString& fileName, int res, bool color)
 {
-	if ( fileName.isEmpty() ){
+	if (fileName.isEmpty()){
 		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please provide a valid file name!"));
-        return;
+		return;
 	}
 
 	QPrinter printer;
-    printer.setCreator("QtiPlot");
-	printer.setFullPage(true);
-	if (res)
-		printer.setResolution(res);
+	printer.setOutputFileName(fileName);
+	if (fileName.contains(".eps"))
+		printer.setOutputFormat(QPrinter::PostScriptFormat);
 
-    printer.setOutputFileName(fileName);
-    if (fileName.contains(".eps"))
-    	printer.setOutputFormat(QPrinter::PostScriptFormat);
-
-    if (color)
-		printer.setColorMode(QPrinter::Color);
-	else
-		printer.setColorMode(QPrinter::GrayScale);
-
-	printer.setOrientation(QPrinter::Portrait);
-
-    int cols = numCols();
-    int rows = numRows();
-    QRect rect = QRect(0, 0, cols, rows);
-    printer.setPaperSize(QSizeF(cols, rows), QPrinter::DevicePixel);
-
-    QPainter paint(&printer);
-    paint.drawImage(rect, d_matrix_model->renderImage());
-    paint.end();
+	exportVector(&printer, res, color);
 }
 
 void Matrix::exportEMF(const QString& fileName)
@@ -1186,7 +1204,17 @@ void Matrix::range(double *min, double *max)
 	*max = d_max;
 }
 
-double** Matrix::allocateMatrixData(int rows, int columns)
+QwtDoubleInterval Matrix::colorRange()
+{
+	if (d_color_map.intensityRange().isValid())
+		return d_color_map.intensityRange();
+
+	double minValue = 0.0, maxValue = 0.0;
+	range(&minValue, &maxValue);
+	return QwtDoubleInterval(minValue, maxValue);
+}
+
+double** Matrix::allocateMatrixData(int rows, int columns, bool init)
 {
 	double** data = (double **)malloc(rows * sizeof (double*));
 	if(!data){
@@ -1195,6 +1223,22 @@ double** Matrix::allocateMatrixData(int rows, int columns)
 		return NULL;
 	}
 
+	if (init){
+		for ( int i = 0; i < rows; ++i){
+			data[i] = (double *)calloc(columns, sizeof(double));
+			if(!data[i]){
+				for ( int j = 0; j < i; j++)
+					free(data[j]);
+				free(data);
+
+				QMessageBox::critical(0, tr("QtiPlot") + " - " + tr("Memory Allocation Error"),
+				tr("Not enough memory, operation aborted!"));
+				return NULL;
+			}
+		}
+		return data;
+	}
+
 	for ( int i = 0; i < rows; ++i){
 		data[i] = (double *)malloc(columns * sizeof (double));
 		if(!data[i]){
@@ -1332,7 +1376,7 @@ void Matrix::initImageView()
     imageLabel = new QLabel();
     imageLabel->setBackgroundRole(QPalette::Base);
     imageLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
-    imageLabel->setScaledContents(true);
+	imageLabel->setScaledContents(true);
     imageLabel->installEventFilter(this);
     d_stack->addWidget(imageLabel);
 }
@@ -1380,8 +1424,8 @@ QImage Matrix::image()
 void Matrix::importImage(const QString& fn)
 {
 	QImage image(fn);
-    if (image.isNull())
-        return;
+	if (image.isNull())
+		return;
 
 	x_start = 0.0;
 	x_end = image.width() - 1.0;
@@ -1390,7 +1434,7 @@ void Matrix::importImage(const QString& fn)
 
 	double *buffer = d_matrix_model->dataCopy();
 	if (buffer){
-    	d_undo_stack->push(new MatrixSetImageCommand(d_matrix_model, image, d_view_type, 0,
+		d_undo_stack->push(new MatrixSetImageCommand(d_matrix_model, image, d_view_type, 0,
 							numRows() - 1, 0, numCols() - 1, buffer, tr("Import Image") + " \"" + fn + "\""));
 		emit modifiedWindow(this);
 		modifiedData(this);
@@ -1437,7 +1481,7 @@ void Matrix::setDefaultColorMap()
 void Matrix::setGrayScale()
 {
     d_color_map_type = GrayScale;
-	d_color_map = QwtLinearColorMap(Qt::black, Qt::white);
+	d_color_map = LinearColorMap(Qt::black, Qt::white);
 	if (d_view_type == ImageView)
 		displayImage(d_matrix_model->renderImage());
 	emit modifiedWindow(this);
@@ -1447,7 +1491,7 @@ void Matrix::setRainbowColorMap()
 {
     d_color_map_type = Rainbow;
 
-	d_color_map = QwtLinearColorMap(Qt::blue, Qt::red);
+	d_color_map = LinearColorMap(Qt::blue, Qt::red);
 	d_color_map.addColorStop(0.25, Qt::cyan);
 	d_color_map.addColorStop(0.5, Qt::green);
 	d_color_map.addColorStop(0.75, Qt::yellow);
@@ -1457,7 +1501,7 @@ void Matrix::setRainbowColorMap()
 	emit modifiedWindow(this);
 }
 
-void Matrix::setColorMap(const QwtLinearColorMap& map)
+void Matrix::setColorMap(const LinearColorMap& map)
 {
 	d_color_map_type = Custom;
 	d_color_map = map;
@@ -1467,31 +1511,6 @@ void Matrix::setColorMap(const QwtLinearColorMap& map)
 	emit modifiedWindow(this);
 }
 
-void Matrix::setColorMap(const QStringList& lst)
-{
-	d_color_map_type = Custom;
-
-	QStringList::const_iterator line = lst.begin();
-  	QString s = (*line).stripWhiteSpace();
-
-	int mode = s.remove("<Mode>").remove("</Mode>").stripWhiteSpace().toInt();
-    s = *(++line);
-    QColor color1 = QColor(s.remove("<MinColor>").remove("</MinColor>").stripWhiteSpace());
-    s = *(++line);
-    QColor color2 = QColor(s.remove("<MaxColor>").remove("</MaxColor>").stripWhiteSpace());
-
-	d_color_map = QwtLinearColorMap(color1, color2);
-	d_color_map.setMode((QwtLinearColorMap::Mode)mode);
-
-	s = *(++line);
-	int stops = s.remove("<ColorStops>").remove("</ColorStops>").stripWhiteSpace().toInt();
-	for (int i = 0; i < stops; i++){
-		s = (*(++line)).stripWhiteSpace();
-		QStringList l = QStringList::split("\t", s.remove("<Stop>").remove("</Stop>"));
-		d_color_map.addColorStop(l[0].toDouble(), QColor(l[1]));
-	}
-}
-
 void Matrix::setColorMapType(ColorMapType mapType)
 {
 	d_color_map_type = mapType;
@@ -1777,7 +1796,7 @@ bool Matrix::eventFilter(QObject *object, QEvent *e)
 	if (object != (QObject*)imageLabel)
 		return MdiSubWindow::eventFilter(object, e);
 
-	if (e->type() == QEvent::MouseButtonPress && object == (QObject*)imageLabel){
+	if (e->type() == QEvent::MouseButtonPress){
 		const QMouseEvent *me = (const QMouseEvent *)e;
 		if (me->button() == Qt::LeftButton){
 			QDrag *drag = new QDrag(this);
@@ -1789,6 +1808,9 @@ bool Matrix::eventFilter(QObject *object, QEvent *e)
 		}
 	}
 
+	if (e->type() == QEvent::Resize)
+		displayImage(d_matrix_model->renderImage());
+
 	return QObject::eventFilter(object, e);
 }
 
