@@ -62,6 +62,7 @@ class ApplicationWindow;
 class Matrix;
 class SelectionMoveResizer;
 class RangeSelectorTool;
+class ImageProfilesTool;
 class DataCurve;
 class PlotCurve;
 class ErrorBarsCurve;
@@ -135,7 +136,7 @@ class Graph: public QwtPlot
 			Spline, HorizontalSteps, Histogram, HorizontalBars, VectXYXY, ErrorBars,
 			Box, VectXYAM, VerticalSteps, ColorMap, GrayScale, Contour, Function, ImagePlot,
 			StackBar, StackColumn};
-		enum LegendDisplayMode{ColumnName, ColumnComment, TableName, TableLegend};
+		enum LegendDisplayMode{Auto, ColumnName, ColumnComment, TableName, TableLegend};
 		enum AxisTitlePolicy{Default, ColName, ColComment, NameAndComment};
 
 		//! Returns a pointer to the parent MultiLayer object.
@@ -170,6 +171,7 @@ class Graph: public QwtPlot
 
 		Grid *grid(){return (Grid *)d_grid;};
 		QList<QwtPlotItem *> curvesList(){return d_curves;};
+		void setCurvesList(QList<QwtPlotItem *> lst){d_curves = lst;};
 
 		QwtPlotItem* closestCurve(int xpos, int ypos, int &dist, int &point);
 
@@ -226,18 +228,24 @@ class Graph: public QwtPlot
 		static QString texSuperscripts(const QString &);
 #endif
 		void changeCurveIndex(int fromIndex, int toIndex);
-		void enableDouglasPeukerSpeedMode(double tolerance, int maxPoints);
+		void enableDouglasPeukerSpeedMode(double tolerance, int maxPoints = 3000);
 
 		int speedModeMaxPoints(){return d_speed_mode_points;};
 		double getDouglasPeukerTolerance(){return d_Douglas_Peuker_tolerance;};
 
 		AxisTitlePolicy axisTitlePolicy(){return d_axis_title_policy;};
 		void setAxisTitlePolicy(const AxisTitlePolicy& policy){d_axis_title_policy = policy;};
+
+		bool hasSynchronizedScaleDivisions(){return d_synchronize_scales;};
 		void setSynchronizedScaleDivisions(bool on){d_synchronize_scales = on;};
 
+		QRectF pageGeometry(){return d_page_rect;}
+		void setPageGeometry(const QRectF& r){d_page_rect = r;}
+
 	public slots:
 		void copy(Graph* g);
 		void copyCurves(Graph* g);
+		void copyEnrichments(Graph* g);
 		void copyScaleWidget(Graph* g, int i);
 		void copyScaleDraw(Graph* g, int i);
 
@@ -264,6 +272,7 @@ class Graph: public QwtPlot
 		DataCurve* insertCurve(Table* w, const QString& name, int style, int startRow = 0, int endRow = -1);
 		DataCurve* insertCurve(Table* w, int xcol, const QString& name, int style);
 		DataCurve* insertCurve(Table* w, const QString& xColName, const QString& yColName, int style, int startRow = 0, int endRow = -1);
+		DataCurve* insertCurve(Table* xt, const QString& xColName, Table* yt, const QString& yColName, int style, int startRow = 0, int endRow = -1);
 		void insertPlotItem(QwtPlotItem *i, int type);
 		void insertCurve(QwtPlotItem *c);
 
@@ -303,6 +312,8 @@ class Graph: public QwtPlot
 		PlotCurve* curve(const QString &title){return curve(curveIndex(title));};
 		//! get curve title string by inde (convenience function for scripts)
 		QString curveTitle(int index);
+		//! returns the curve range information as a string: "curve_name [start:end]"
+		QString curveRange(QwtPlotCurve *c);
 
 		//! Returns the names of all the curves suitable for data analysis, as a string list. The list excludes error bars and spectrograms.
 		QStringList analysableCurvesList();
@@ -346,9 +357,11 @@ class Graph: public QwtPlot
 #endif
 		void exportVector(const QString& fileName, int res = 0, bool color = true,
 						const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+		void exportVector(QPrinter *printer, int res = 0, bool color = true,
+						  const QSizeF& customSize = QSizeF (), int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
 		void exportImage(const QString& fileName, int quality = 100, bool transparent = false,
 						 int dpi = 0, const QSizeF& customSize = QSizeF (),
-						 int unit = FrameWidget::Pixel, double fontsFactor = 1.0);
+						 int unit = FrameWidget::Pixel, double fontsFactor = 1.0, int compression = 0);
 
 		void draw(QPaintDevice *, const QSize& size, double fontsFactor = 1.0);
 		static QSize customPrintSize(const QSizeF& customSize, int unit, int dpi);
@@ -534,6 +547,7 @@ class Graph: public QwtPlot
 		void setAxisTitleString(int axis, const QString& text);
 		void setAxisTitle(int axis, const QString& text);
 		void updateAxesTitles();
+		void updateAxisTitle(int axis);
 		//! TODO: eliminate this function in version 0.9.1 (used only when restoring project files)
 		void setScaleTitle(int axis, const QString& text);
 
@@ -595,6 +609,7 @@ class Graph: public QwtPlot
 		void setLabelsDateTimeFormat(int axis, int type, const QString& formatInfo);
 		void setLabelsDayFormat(int axis, int format);
 		void setLabelsMonthFormat(int axis, int format);
+		void recoverObsoleteDateTimeScale(int axis, int type, const QString& origin, const QString& format);
 
 		QString axisFormatInfo(int axis);
 
@@ -635,6 +650,8 @@ class Graph: public QwtPlot
 		//@}
 
 		void disableTools();
+		void disableImageProfilesTool();
+		QPointer<ImageProfilesTool> imageProfilesTool(){return d_image_profiles_tool;}
 
 		/*! Enables the data range selector tool.
 		 *
@@ -708,6 +725,8 @@ class Graph: public QwtPlot
 		void notifyChanges();
 
 		void updateSecondaryAxis(int axis, bool changeFormat = false);
+		int oppositeAxis(int axis);
+		void updateOppositeScaleDiv(int axis);
 
 		bool isAutoscalingEnabled(){return d_auto_scale;};
 		void enableAutoscaling(bool on = true){d_auto_scale = on;};
@@ -738,6 +757,8 @@ class Graph: public QwtPlot
 		void showGrid();
 		//! Convenience function enabling the grid for a user defined axis
 		void showGrid(int axis);
+		void setGridOnTop(bool on = true, bool update = true);
+		bool hasGridOnTop(){return d_grid_on_top;}
 
 		void showAxisDialog();
 		void showScaleDialog();
@@ -768,6 +789,24 @@ class Graph: public QwtPlot
 		void notifyFontChange(const QFont& f){emit currentFontChanged(f);};
         void enableTextEditor();
 
+		void showMissingDataGap(bool on = true, bool update = true);
+		bool isMissingDataGapEnabled(){return d_missing_data_gap;}
+
+		//! \name Waterfall
+		//@{
+		bool isWaterfallPlot(){return d_waterfall_offset_x != 0 || d_waterfall_offset_y != 0;};
+		int waterfallXOffset(){return d_waterfall_offset_x;};
+		int waterfallYOffset(){return d_waterfall_offset_y;};
+		void setWaterfallOffset(int x, int y, bool update = false);
+		void setWaterfallXOffset(int);
+		void setWaterfallYOffset(int);
+		void setWaterfallSideLines(bool on = true);
+		void setWaterfallFillColor(const QColor&);
+		void updateWaterfallFill(bool on);
+		//@}
+		void updateDataCurves();
+		void reverseCurveOrder();
+
 signals:
 		void selectedGraph(Graph*);
 		void selectedCanvas(Graph*);
@@ -842,6 +881,10 @@ signals:
 		bool drawLineOn, drawArrowOn, drawAxesBackbone;
 		//! Flag telling if we are performing a print operation
 		bool d_is_printing;
+		//! Flag telling if the grid should be drawn on top of data
+		bool d_grid_on_top;
+		//! Flag telling if the curves line should be connected across missing data
+		bool d_missing_data_gap;
 		//! Stores the step the user specified for the four scale. If step = 0.0, the step will be calculated automatically by the Qwt scale engine.
 		QVector<double> d_user_step;
 		//! Arrows/lines on plot
@@ -852,6 +895,7 @@ signals:
 		QPointer<SelectionMoveResizer> d_markers_selector;
 		//! The current curve selection, or NULL if none is active.
 		QPointer<RangeSelectorTool> d_range_selector;
+		QPointer<ImageProfilesTool> d_image_profiles_tool;
 		//! The currently active tool, or NULL for default (pointer).
 		PlotToolInterface *d_active_tool, *d_peak_fit_tool;
 		//! Pointer to the currently selected text/legend
@@ -876,5 +920,32 @@ signals:
 
 		QString d_canvas_bkg_path;
 		QPixmap d_canvas_bkg_pix;
+
+		int d_waterfall_offset_x, d_waterfall_offset_y;
+		QRectF d_page_rect;
+};
+
+class ScaledFontsPrintFilter: public QwtPlotPrintFilter
+{
+
+public:
+	ScaledFontsPrintFilter(double factor){d_factor = factor;};
+	virtual QFont font(const QFont &f, Item item) const
+	{
+		if (d_factor == 1.0 || d_factor <= 0.0)
+			return f;
+
+		if (item == Title || item == AxisScale || item == AxisTitle || item == Marker){
+			QFont fnt(f);
+			fnt.setPointSizeF(d_factor*f.pointSizeF());
+			return fnt;
+		}
+		return f;
+	}
+
+	double scaleFontsFactor(){return d_factor;}
+
+private:
+	double d_factor;
 };
 #endif // GRAPH_H
