@@ -76,6 +76,7 @@
 #include <ColorButton.h>
 #include <ScaleEngine.h>
 #include <ImportExportPlugin.h>
+#include <ScreenPickerTool.h>
 
 #include <gsl/gsl_vector.h>
 
@@ -126,11 +127,8 @@ vert_align(VCenter),
 d_scale_on_print(true),
 d_print_cropmarks(false),
 d_scale_layers(parent->autoResizeLayers),
-d_waterfall_offset_x(1),
-d_waterfall_offset_y(3),
 d_is_waterfall_plot(false),
-d_side_lines(false),
-d_waterfall_fill_color(QColor()),
+d_waterfall_fill_color(Qt::black),
 d_canvas_size(QSize()),
 d_align_policy(AlignLayers),
 d_size_policy(UserSize),
@@ -255,11 +253,6 @@ Graph* MultiLayer::addLayer(int x, int y, int width, int height, bool setPrefere
 	return g;
 }
 
-void MultiLayer::adjustSize()
-{
-    d_canvas->resize(size().width(), size().height() - LayerButton::btnSize());
-}
-
 void MultiLayer::activateGraph(LayerButton* button)
 {
 	for (int i = 0; i<buttonsList.count(); i++){
@@ -303,11 +296,9 @@ Graph* MultiLayer::clickedLayer(Graph* g)
 			continue;
 
 		QPoint pos = gr->mapFromGlobal(QCursor::pos());
-		if (ar.contains(gr->frameGeometry()) && gr->rect().contains(pos)){
+		if ((ar.contains(gr->frameGeometry()) && gr->rect().contains(pos)))
 			return gr;
-		}
 	}
-
 	return g;
 }
 
@@ -329,17 +320,19 @@ void MultiLayer::selectLayerCanvas(Graph* g)
 
 void MultiLayer::setActiveLayer(Graph* g)
 {
-	Graph *ag = clickedLayer(g);
+	/*Graph *ag = clickedLayer(g);
 	if (!ag || active_graph == ag)
+		return;*/
+
+	if (!g || active_graph == g)
 		return;
 
-	active_graph = ag;
+	active_graph = g;
 	active_graph->setFocus();
 
 	deselect();
 
-	if (!d_is_waterfall_plot)
-		active_graph->raise();//raise layer on top of the layers stack
+	active_graph->raise();//raise layer on top of the layers stack
 	active_graph->raiseEnrichements();
 
 	for(int i = 0; i < graphsList.count(); i++){
@@ -347,7 +340,7 @@ void MultiLayer::setActiveLayer(Graph* g)
 		gr->deselect();
 
 		LayerButton *btn = (LayerButton *)buttonsList.at(i);
-		if (gr == ag)
+		if (gr == g)
 			btn->setOn(true);
 		else
 			btn->setOn(false);
@@ -363,7 +356,22 @@ QRect MultiLayer::canvasChildrenRect()
 	return r.adjusted(0, 0, right_margin, bottom_margin);
 }
 
-void MultiLayer::resizeLayers (QResizeEvent *re)
+void MultiLayer::adjustLayersToCanvasSize()
+{
+	foreach (Graph *g, graphsList){
+		QRectF rf = g->pageGeometry();
+		if (rf.isNull())
+			continue;
+
+		int x = qRound(rf.x()*d_canvas->width());
+		int y = qRound(rf.y()*d_canvas->height());
+		int w = qRound(rf.width()*d_canvas->width());
+		int h = qRound(rf.height()*d_canvas->height());
+		g->setGeometry(x, y, w, h);
+	}
+}
+
+void MultiLayer::resizeLayers(QResizeEvent *re)
 {
 	if (!d_scale_layers || applicationWindow()->d_opening_file || graphsList.isEmpty()){
 		if (!applicationWindow()->d_opening_file)
@@ -378,33 +386,21 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 		size.setHeight(oldSize.height());
 
 	bool invalidOldSize = !oldSize.isValid();
-	if (invalidOldSize){// The old size is invalid when maximizing a window (why?)
+	if (invalidOldSize){
+		//The old size is invalid when maximizing a window or when a minimized window is restored from a project file
 		if (d_canvas_size.isValid())
 			oldSize = d_canvas_size;
-		else {
-			QRect r = canvasChildrenRect();
-			oldSize = QSize(r.width() + left_margin + right_margin, r.height() + top_margin + bottom_margin);
-		}
+		else if (this->isMaximized()){
+			adjustLayersToCanvasSize();
+			return;
+		} else
+			return;
 	}
 
-	double w_ratio = (double)size.width()/(double)oldSize.width();
-	double h_ratio = (double)(size.height())/(double)(oldSize.height());
-
-	if (isWaterfallPlot()){
-		foreach (Graph *g, graphsList){
-			int gx = qRound(g->x()*w_ratio);
-			int gy = qRound(g->y()*h_ratio);
-			int gw = qRound(g->width()*w_ratio);
-			int gh = qRound(g->height()*h_ratio);
-			g->setGeometry(gx, gy, gw, gh);
-		}
-		foreach (Graph *g, graphsList){
-			if (g->autoscaleFonts())
-				g->scaleFonts(h_ratio);
-		}
-		emit modifiedPlot();
-		return;
-	}
+	double w = (double)size.width();
+	double h = (double)size.height();
+	double w_ratio = w/(double)oldSize.width();
+	double h_ratio = h/(double)(oldSize.height());
 
 	if (d_common_axes_layout && !invalidOldSize){
 		arrangeLayers(false, false);
@@ -466,6 +462,12 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 		}
 	}
 
+	foreach (Graph *g, graphsList)
+		g->setPageGeometry(QRectF((double)g->x()/w, (double)g->y()/h, (double)g->width()/w, (double)g->height()/h));
+
+	if (d_is_waterfall_plot)
+		updateWaterfalls();
+
 	emit modifiedPlot();
 }
 
@@ -953,17 +955,16 @@ QPixmap MultiLayer::canvasPixmap(const QSize& size, double scaleFontsFactor, boo
 
 		QList<Graph*> lst = stackOrderedLayersList();
 		foreach (Graph *g, lst)
-			g->print(&p, g->geometry());
+			g->print(&p, g->geometry(), ScaledFontsPrintFilter(1.0));
 
 		p.end();
 		return pic;
 	}
 
-	QRect canvasRect = d_canvas->rect();
-	double scaleFactorX = (double)size.width()/(double)canvasRect.width();
-	double scaleFactorY = (double)size.height()/(double)canvasRect.height();
-	if (scaleFontsFactor == 0)
-		scaleFontsFactor = scaleFactorY;
+	double xScale = (double)size.width()/(double)d_canvas->width();
+	double yScale = (double)(size.height())/(double)(d_canvas->height());
+	if (scaleFontsFactor == 0.0)
+		scaleFontsFactor = yScale;
 
 	QPixmap pic(size);
 	if (transparent)
@@ -974,16 +975,14 @@ QPixmap MultiLayer::canvasPixmap(const QSize& size, double scaleFontsFactor, boo
 
 	QList<Graph*> lst = stackOrderedLayersList();
 	foreach (Graph *g, lst){
-		QPoint pos = g->pos();
-		pos = QPoint(int(pos.x()*scaleFactorX), int(pos.y()*scaleFactorY));
+		int gx = qRound(g->x()*xScale);
+		int gy = qRound(g->y()*yScale);
+		int gw = qRound(g->width()*xScale);
+		int gh = qRound(g->height()*yScale);
 
-		int width = int(g->frameGeometry().width()*scaleFactorX);
-		int height = int(g->frameGeometry().height()*scaleFactorY);
-
-		g->scaleFonts(scaleFontsFactor);
-		g->print(&p, QRect(pos, QSize(width, height)));
-		g->scaleFonts(1.0/scaleFontsFactor);
+		g->print(&p, QRect(gx, gy, gw, gh), ScaledFontsPrintFilter(scaleFontsFactor));
 	}
+
 	p.end();
 	return pic;
 }
@@ -1024,7 +1023,7 @@ void MultiLayer::exportToFile(const QString& fileName)
 }
 
 void MultiLayer::exportImage(const QString& fileName, int quality, bool transparent,
-				int dpi, const QSizeF& customSize, int unit, double fontsFactor)
+				int dpi, const QSizeF& customSize, int unit, double fontsFactor, int compression)
 {
 	if (!dpi)
 		dpi = logicalDpiX();
@@ -1051,7 +1050,15 @@ void MultiLayer::exportImage(const QString& fileName, int quality, bool transpar
 		writer.write(document);
 	} else
 #endif
-		image.save(fileName, 0, quality);
+	{
+		QImageWriter writer(fileName);
+		if (compression > 0 && writer.supportsOption(QImageIOHandler::CompressionRatio)){
+			writer.setQuality(quality);
+			writer.setCompression(compression);
+			writer.write(image);
+		} else
+			image.save(fileName, 0, quality);
+	}
 }
 
 #if QT_VERSION >= 0x040500
@@ -1108,38 +1115,31 @@ void MultiLayer::exportPDF(const QString& fname)
 	exportVector(fname);
 }
 
-void MultiLayer::exportVector(const QString& fileName, int res, bool color,
+void MultiLayer::exportVector(QPrinter *printer, int res, bool color,
 				const QSizeF& customSize, int unit, double fontsFactor)
 {
-	if ( fileName.isEmpty() ){
-		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please provide a valid file name!"));
+	if (!printer)
 		return;
-	}
+	if (!printer->resolution())
+		printer->setResolution(logicalDpiX());//we set screen resolution as default
 
-	QPrinter printer;
-	if (!printer.resolution())
-		printer.setResolution(logicalDpiX());//we set screen resolution as default
-
-    printer.setDocName (objectName());
-    printer.setFontEmbeddingEnabled(true);
-    printer.setCreator("QtiPlot");
-	printer.setFullPage(true);
-	printer.setOutputFileName(fileName);
-    if (fileName.contains(".eps"))
-    	printer.setOutputFormat(QPrinter::PostScriptFormat);
+	printer->setDocName (objectName());
+	printer->setFontEmbeddingEnabled(true);
+	printer->setCreator("QtiPlot");
+	printer->setFullPage(true);
 
 	if (color)
-		printer.setColorMode(QPrinter::Color);
+		printer->setColorMode(QPrinter::Color);
 	else
-		printer.setColorMode(QPrinter::GrayScale);
+		printer->setColorMode(QPrinter::GrayScale);
 
-	printer.setOrientation(QPrinter::Portrait);
+	printer->setOrientation(QPrinter::Portrait);
 	if (customSize.isValid()){
 		QSize size = Graph::customPrintSize(customSize, unit, res);
-		if (res && res != printer.resolution())
-			printer.setResolution(res);
-		printer.setPaperSize (QSizeF(size), QPrinter::DevicePixel);
-		QPainter paint(&printer);
+		if (res && res != printer->resolution())
+			printer->setResolution(res);
+		printer->setPaperSize (QSizeF(size), QPrinter::DevicePixel);
+		QPainter paint(printer);
 		QList<Graph*> lst = stackOrderedLayersList();
 		foreach (Graph *g, lst){
 			QRect r = g->geometry();
@@ -1151,32 +1151,49 @@ void MultiLayer::exportVector(const QString& fileName, int res, bool color,
 			if (fontsFactor == 0.0)
 				fontsFactor = Graph::customPrintSize(customSize, unit, logicalDpiX()).height()/(double)height();
 
-			g->scaleFonts(fontsFactor);
-        	g->print(&paint, r);
-        	g->scaleFonts(1.0/fontsFactor);
+			g->print(&paint, r, ScaledFontsPrintFilter(fontsFactor));
 		}
-	} else if (res && res != printer.resolution()){
+		paint.end();
+	} else if (res && res != printer->resolution()){
 		double wfactor = (double)res/(double)logicalDpiX();
 		double hfactor = (double)res/(double)logicalDpiY();
-		printer.setResolution(res);
-		printer.setPaperSize (QSizeF(d_canvas->width()*wfactor*1.05, d_canvas->height()*hfactor), QPrinter::DevicePixel);
-		QPainter paint(&printer);
+		printer->setResolution(res);
+		printer->setPaperSize (QSizeF(d_canvas->width()*wfactor*1.05, d_canvas->height()*hfactor), QPrinter::DevicePixel);
+		QPainter paint(printer);
 		QList<Graph*> lst = stackOrderedLayersList();
 		foreach (Graph *g, lst){
 			QRect r = g->geometry();
 			r.setSize(QSize(int(r.width()*wfactor), int(r.height()*hfactor)));
 			r.moveTo(int(r.x()*wfactor), int(r.y()*hfactor));
-			g->print(&paint, r);
+			g->print(&paint, r, ScaledFontsPrintFilter(fontsFactor));
 		}
+		paint.end();
 	} else {
-    	printer.setPaperSize(QSizeF(d_canvas->width(), d_canvas->height()), QPrinter::DevicePixel);
-		QPainter paint(&printer);
+		printer->setPaperSize(QSizeF(d_canvas->width(), d_canvas->height()), QPrinter::DevicePixel);
+		QPainter paint(printer);
 		QList<Graph*> lst = stackOrderedLayersList();
 		foreach (Graph *g, lst)
-			g->print(&paint, g->geometry());
+			g->print(&paint, g->geometry(), ScaledFontsPrintFilter(fontsFactor));
+		paint.end();
 	}
 }
 
+void MultiLayer::exportVector(const QString& fileName, int res, bool color,
+				const QSizeF& customSize, int unit, double fontsFactor)
+{
+	if (fileName.isEmpty()){
+		QMessageBox::critical(this, tr("QtiPlot - Error"), tr("Please provide a valid file name!"));
+		return;
+	}
+
+	QPrinter printer;
+	printer.setOutputFileName(fileName);
+	if (fileName.contains(".eps"))
+		printer.setOutputFormat(QPrinter::PostScriptFormat);
+
+	exportVector(&printer, res, color, customSize, unit, fontsFactor);
+}
+
 void MultiLayer::draw(QPaintDevice *device, const QSizeF& customSize, int unit, int res, double fontsFactor)
 {
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -1196,14 +1213,12 @@ void MultiLayer::draw(QPaintDevice *device, const QSizeF& customSize, int unit,
 			if (fontsFactor == 0.0)
 				fontsFactor = Graph::customPrintSize(customSize, unit, logicalDpiX()).height()/(double)height();
 
-			g->scaleFonts(fontsFactor);
-        	g->print(&paint, r);
-        	g->scaleFonts(1.0/fontsFactor);
+			g->print(&paint, r, ScaledFontsPrintFilter(fontsFactor));
 		}
 	} else {
 		QList<Graph*> lst = stackOrderedLayersList();
 		foreach (Graph *g, lst)
-			g->print(&paint, g->geometry());
+			g->print(&paint, g->geometry(), ScaledFontsPrintFilter(fontsFactor));
 	}
 	paint.end();
 	QApplication::restoreOverrideCursor();
@@ -1336,9 +1351,7 @@ void MultiLayer::print()
 		}
 	#endif
 
-		QPainter paint(&printer);
-		printAllLayers(&paint);
-		paint.end();
+		print(&printer);
 	}
 }
 
@@ -1364,16 +1377,16 @@ void MultiLayer::printAllLayers(QPainter *painter)
 	QRect cr = canvasRect; // cropmarks rectangle
 
 	if (d_scale_on_print){
-        int margin = (int)((1/2.54)*printer->logicalDpiY()); // 1 cm margins
-		double scaleFactorX=(double)(paperRect.width()-2*margin)/(double)canvasRect.width();
-		double scaleFactorY=(double)(paperRect.height()-2*margin)/(double)canvasRect.height();
+		int margin = (int)((1/2.54)*printer->logicalDpiY()); // 1 cm margins
+		double scaleFactorX = (double)(paperRect.width() - 2*margin)/(double)canvasRect.width();
+		double scaleFactorY = (double)(paperRect.height() - 2*margin)/(double)canvasRect.height();
 
-        if (d_print_cropmarks){
+		if (d_print_cropmarks){
 			cr.moveTo(QPoint(margin + int(cr.x()*scaleFactorX),
 							 margin + int(cr.y()*scaleFactorY)));
 			cr.setWidth(int(cr.width()*scaleFactorX));
 			cr.setHeight(int(cr.height()*scaleFactorY));
-        }
+		}
 
 		foreach (Graph *g, graphsList){
 			QPoint pos = g->pos();
@@ -1382,25 +1395,29 @@ void MultiLayer::printAllLayers(QPainter *painter)
 			int width = int(g->frameGeometry().width()*scaleFactorX);
 			int height = int(g->frameGeometry().height()*scaleFactorY);
 
-			g->print(painter, QRect(pos, QSize(width,height)));
+			g->print(painter, QRect(pos, QSize(width,height)), ScaledFontsPrintFilter(scaleFactorY));
 		}
 	} else {
-    	int x_margin = (pageRect.width() - canvasRect.width())/2;
-    	int y_margin = (pageRect.height() - canvasRect.height())/2;
+		int x_margin = (pageRect.width() - canvasRect.width())/2;
+		if (x_margin <= 0)
+			x_margin = (int)((0.5/2.54)*printer->logicalDpiY()); // 0.5 cm margins
+		int y_margin = (pageRect.height() - canvasRect.height())/2;
+		if (y_margin <= 0)
+			y_margin = x_margin;
 
-        if (d_print_cropmarks)
-            cr.moveTo(x_margin, y_margin);
+		if (d_print_cropmarks)
+			cr.moveTo(x_margin, y_margin);
 
 		foreach (Graph *g, graphsList){
 			QPoint pos = g->pos();
 			pos = QPoint(x_margin + pos.x(), y_margin + pos.y());
-			g->print(painter, QRect(pos, g->size()));
+			g->print(painter, QRect(pos, g->size()), ScaledFontsPrintFilter(1.0));
 		}
 	}
 
 	if (d_print_cropmarks){
 		cr.addCoords(-1, -1, 2, 2);
-    	painter->save();
+		painter->save();
 		painter->setPen(QPen(QColor(Qt::black), 0.5, Qt::DashLine));
 		painter->drawLine(paperRect.left(), cr.top(), paperRect.right(), cr.top());
 		painter->drawLine(paperRect.left(), cr.bottom(), paperRect.right(), cr.bottom());
@@ -1408,7 +1425,6 @@ void MultiLayer::printAllLayers(QPainter *painter)
 		painter->drawLine(cr.right(), paperRect.top(), cr.right(), paperRect.bottom());
 		painter->restore();
 	}
-
 }
 
 void MultiLayer::setFonts(const QFont& titleFnt, const QFont& scaleFnt,
@@ -1478,9 +1494,6 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 		} else if (me->button() == Qt::MidButton)
 			return QMdiSubWindow::eventFilter(object, e);
 
-		if (d_is_waterfall_plot)
-			return true;
-
 		QPoint pos = d_canvas->mapFromGlobal(me->globalPos());
 		// iterate backwards, so layers on top are preferred for selection
 		QList<Graph*>::iterator i = graphsList.end();
@@ -1523,10 +1536,16 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 
 void MultiLayer::mouseReleaseEvent( QMouseEvent * e)
 {
-	d_layer_coordinates.resize(0);
+	d_layer_coordinates.clear();
 	return QMdiSubWindow::mouseReleaseEvent(e);
 }
 
+void MultiLayer::showEvent (QShowEvent * e)
+{
+	d_layer_coordinates.clear();
+	return QMdiSubWindow::showEvent(e);
+}
+
 void MultiLayer::keyPressEvent(QKeyEvent * e)
 {
 	if (e->key() == Qt::Key_Escape){
@@ -1657,11 +1676,8 @@ void MultiLayer::save(const QString &fn, const QString &geometry, bool saveAsTem
 	foreach (Graph *g, graphsList)
 		t << g->saveToString(saveAsTemplate);
 
-	if (d_is_waterfall_plot){
-		t << "<waterfall>" + QString::number(d_waterfall_offset_x) + ",";
-		t << QString::number(d_waterfall_offset_y) + ",";
-		t << QString::number(d_side_lines) + "</waterfall>\n";
-	}
+	if (d_is_waterfall_plot)
+		t << "<waterfall>1</waterfall>\n";
 
 	t << "<LinkXAxes>" + QString::number(d_link_x_axes) + "</LinkXAxes>\n";
 	t << "<ScaleLayers>" + QString::number(d_scale_layers) + "</ScaleLayers>\n";
@@ -1765,7 +1781,7 @@ void MultiLayer::copy(MultiLayer* ml)
 	d_scale_on_print = ml->scaleLayersOnPrint();
 	d_print_cropmarks = ml->printCropmarksEnabled();
 
-	QList<Graph*> lst = ml->stackOrderedLayersList();
+	QList<Graph*> lst = ml->layersList();
 	foreach (Graph *g, lst){
 		Graph* g2 = addLayer(g->pos().x(), g->pos().y(), g->width(), g->height());
 		g2->setAutoscaleFonts(false);
@@ -1773,12 +1789,17 @@ void MultiLayer::copy(MultiLayer* ml)
 		g2->setAutoscaleFonts(g->autoscaleFonts());
 	}
 
-	if (ml->isWaterfallPlot()){
-		d_waterfall_offset_x = ml->waterfallXOffset();
-		d_waterfall_offset_y = ml->waterfallYOffset();
-		createWaterfallBox();
-		setWaterfallSideLines(ml->sideLinesEnabled());
-		updateWaterfallLayout();
+	if (ml->isWaterfallPlot())
+		setWaterfallLayout(true);
+
+	foreach (Graph *g, lst){
+		ImageProfilesTool *ipt = g->imageProfilesTool();
+		if (ipt){
+			Graph *g2 = layer(ml->layerIndex(g) + 1);
+			if (g2)
+				g2->setActiveTool(ipt->clone(g2));
+			break;
+		}
 	}
 
 	d_scale_layers = ml->scaleLayersOnResize();
@@ -1850,7 +1871,7 @@ void MultiLayer::setWaterfallLayout(bool on)
 
 	if (on){
 		createWaterfallBox();
-		updateWaterfallLayout();
+		updateWaterfalls();
 	} else {
 		for (int i = 0; i < waterfallBox->count(); i++){
 			QLayoutItem *item = waterfallBox->itemAt(i);
@@ -1864,6 +1885,9 @@ void MultiLayer::setWaterfallLayout(bool on)
 
 void MultiLayer::createWaterfallBox()
 {
+	if (waterfallBox->count() > 0)
+		return;
+
 	QPushButton *btn = new QPushButton(tr("Offset Amount..."));
 	connect (btn, SIGNAL(clicked()), this, SLOT(showWaterfallOffsetDialog()));
 
@@ -1875,106 +1899,26 @@ void MultiLayer::createWaterfallBox()
 	btn = new QPushButton(tr("Fill Area..."));
 	connect (btn, SIGNAL(clicked()), this, SLOT(showWaterfallFillDialog()));
 	waterfallBox->addWidget(btn);
-
-	d_is_waterfall_plot = true;
-
-	foreach(LayerButton *btn, buttonsList)
-		btn->hide();
-
-	d_add_layer_btn->hide();
-	d_remove_layer_btn->hide();
-
-	Graph *first = graphsList.last();
-	if (first)
-		connect(first, SIGNAL(axisDivChanged(Graph *, int)), this, SLOT(updateWaterfallScales(Graph *, int)));
 }
 
-void MultiLayer::updateWaterfallScales(Graph *g, int axis)
-{
-	if (!g)
-		return;
-
-	QwtScaleDiv *scDiv = g->axisScaleDiv(axis);
-	if (!scDiv)
-		return;
-
-	foreach(Graph *l, graphsList){
-		if (l == g)
-			continue;
-
-		l->setAxisScaleDiv(axis, *scDiv);
-		l->replot();
-	}
-}
-
-void MultiLayer::updateWaterfallLayout()
+void MultiLayer::updateWaterfalls()
 {
 	if (!d_is_waterfall_plot || graphsList.isEmpty())
 		return;
 
-	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-	int layers = graphsList.size();
-	int aux = layers - 1;
-	Graph *first = graphsList[aux];
-	bool scaleFonts = first->autoscaleFonts();
-	first->setAutoscaleFonts(false);
-	first->enableAxis(QwtPlot::xBottom, true);
-	first->enableAxis(QwtPlot::yLeft, true);
-	first->enableAxis(QwtPlot::xTop, false);
-	first->enableAxis(QwtPlot::yRight, false);
-
-	if (!first->isVisible())
-		first->show();
-
-	int dx = qRound(d_waterfall_offset_x*d_canvas->width()/100.0);
-	int dy = qRound(d_waterfall_offset_y*d_canvas->height()/100.0);
-	first->resize(QSize(d_canvas->width() - aux*dx - left_margin - right_margin,
-			d_canvas->height() - aux*dy - top_margin - bottom_margin));
-	first->move(first->x(), first->canvas()->y() + aux*dy);
-
-	QSize size = first->canvas()->size();
-	QPoint pos = QPoint(first->canvas()->x() + left_margin,
-						first->canvas()->y() + top_margin);
-
-	QColor c = Qt::white;
-	c.setAlpha(0);
-	first->setBackgroundColor(c);
-	first->setCanvasBackground(c);
-
-	QwtScaleDiv *xScaleDiv = first->axisScaleDiv(QwtPlot::xBottom);
-	QwtScaleDiv *yScaleDiv = first->axisScaleDiv(QwtPlot::yLeft);
-
-	QObjectList lst = d_canvas->children();
-	for (int i = 1; i < layers; i++){
-		Graph *g = qobject_cast<Graph *>(lst[aux - i]);
-		if (!g)
-			continue;
-
-		g->setBackgroundColor(c);
-		g->setCanvasBackground(c);
-
-		for (int j = 0; j < QwtPlot::axisCnt; j++)
-			g->enableAxis(j, false);
-
-		g->move(pos.x() + i*dx, pos.y() + (aux - i)*dy);
-		g->resize(size);
-
-		if (!g->isVisible())
-			g->show();
-
-		g->setAxisScaleDiv(QwtPlot::xBottom, *xScaleDiv);
-		g->setAxisScaleDiv(QwtPlot::yLeft, *yScaleDiv);
+	foreach(Graph *g, graphsList){
+		if (g->isWaterfallPlot())
+			g->updateDataCurves();
 	}
-	first->setAutoscaleFonts(scaleFonts);
-
-	foreach(Graph *g, graphsList)
-		g->updateMarkersBoundingRect();
-	QApplication::restoreOverrideCursor();
 }
 
 void MultiLayer::showWaterfallOffsetDialog()
 {
+	if (graphsList.isEmpty() || !active_graph)
+		return;
+	if (active_graph->curvesList().isEmpty())
+		return;
+
 	QDialog *offsetDialog = new QDialog(this);
 	offsetDialog->setWindowTitle(tr("Offset Dialog"));
 
@@ -1983,22 +1927,22 @@ void MultiLayer::showWaterfallOffsetDialog()
 
 	hl1->addWidget(new QLabel(tr("Total Y Offset (%)")), 0, 0);
 	QSpinBox *yOffsetBox = new QSpinBox();
-	yOffsetBox->setValue(d_waterfall_offset_y);
-	yOffsetBox->setRange(0, 100000);
+	yOffsetBox->setRange(-INT_MAX, INT_MAX);
+	yOffsetBox->setValue(active_graph->waterfallYOffset());
 	hl1->addWidget(yOffsetBox, 0, 1);
 
 	hl1->addWidget(new QLabel(tr("Total X Offset (%)")), 1, 0);
 	QSpinBox *xOffsetBox = new QSpinBox();
-	xOffsetBox->setValue(d_waterfall_offset_x);
-	xOffsetBox->setRange(0, 100000);
+	xOffsetBox->setRange(-INT_MAX, INT_MAX);
+	xOffsetBox->setValue(active_graph->waterfallXOffset());
 	hl1->addWidget(xOffsetBox, 1, 1);
 	hl1->setRowStretch(2, 1);
 
-	connect(yOffsetBox, SIGNAL(valueChanged(int)), this, SLOT(changeWaterfallYOffset(int)));
-	connect(xOffsetBox, SIGNAL(valueChanged(int)), this, SLOT(changeWaterfallXOffset(int)));
+	connect(yOffsetBox, SIGNAL(valueChanged(int)), active_graph, SLOT(setWaterfallYOffset(int)));
+	connect(xOffsetBox, SIGNAL(valueChanged(int)), active_graph, SLOT(setWaterfallXOffset(int)));
 
 	QPushButton *applyBtn = new QPushButton(tr("&Apply"));
-	connect(applyBtn, SIGNAL(clicked()), this, SLOT(updateWaterfallLayout()));
+	connect(applyBtn, SIGNAL(clicked()), this, SLOT(updateWaterfalls()));
 
 	QPushButton *closeBtn = new QPushButton(tr("&Close"));
 	connect(closeBtn, SIGNAL(clicked()), offsetDialog, SLOT(reject()));
@@ -2014,82 +1958,23 @@ void MultiLayer::showWaterfallOffsetDialog()
 	offsetDialog->exec();
 }
 
-void MultiLayer::changeWaterfallXOffset(int offset)
-{
-	if (offset == d_waterfall_offset_x)
-		return;
-
-	d_waterfall_offset_x = offset;
-	updateWaterfallLayout();
-	emit modifiedWindow(this);
-}
-
-void MultiLayer::setWaterfallOffset(int x, int y, bool update)
-{
-	d_waterfall_offset_x = x;
-	d_waterfall_offset_y = y;
-
-	if (update){
-		updateWaterfallLayout();
-		emit modifiedWindow(this);
-	}
-}
-
-void MultiLayer::changeWaterfallYOffset(int offset)
-{
-	if (offset == d_waterfall_offset_y)
-		return;
-
-	d_waterfall_offset_y = offset;
-	updateWaterfallLayout();
-	emit modifiedWindow(this);
-}
-
 void MultiLayer::reverseWaterfallOrder()
 {
-	int layers = graphsList.size();
-	if (layers < 2)
+	if (graphsList.isEmpty() || !active_graph)
 		return;
 
-	QList<QwtPlotItem *> lst;
-	foreach(Graph *g, graphsList){
-		QList <LegendWidget *> texts = g->textsList();
-		QList<bool> autoUpdateLegends;
-		foreach (LegendWidget *l, texts){
-			autoUpdateLegends << l->isAutoUpdateEnabled();
-			l->setAutoUpdate(false);
-		}
-
-		QwtPlotItem *c = g->curve(0);
-		if (c){
-			lst << c;
-			g->removeCurve(c);
-		}
-
-		texts = g->textsList();
-		foreach (LegendWidget *l, texts)
-			l->setAutoUpdate(autoUpdateLegends[texts.indexOf(l)]);
-	}
-
-	if (lst.isEmpty())
-		return;
-
-	for (int i = 0; i < layers; i++){
-		Graph *g = graphsList[i];
-		if (!g)
-			continue;
-
-		int index = layers - i - 1;
-		if (index >= 0 && index < lst.size())
-			g->insertCurve(lst[index]);
-
-		g->replot();
-	}
+	active_graph->reverseCurveOrder();
+	active_graph->updateDataCurves();
 	emit modifiedWindow(this);
 }
 
 void MultiLayer::showWaterfallFillDialog()
 {
+	if (graphsList.isEmpty() || !active_graph)
+		return;
+	if (active_graph->curvesList().isEmpty())
+		return;
+
 	QDialog *waterfallFillDialog = new QDialog(this);
 	waterfallFillDialog->setWindowTitle(tr("Fill Curves"));
 
@@ -2102,23 +1987,17 @@ void MultiLayer::showWaterfallFillDialog()
 	hl1->addWidget(fillColorBox, 0, 1);
 
 	QCheckBox *sideLinesBox = new QCheckBox(tr("Side Lines"));
-	sideLinesBox->setChecked(d_side_lines);
+	sideLinesBox->setChecked(active_graph->curve(0)->sideLinesEnabled());
 	hl1->addWidget(sideLinesBox, 1, 0);
 	hl1->setRowStretch(2, 1);
 
-	if (active_graph){
-		QwtPlotCurve *cv = (QwtPlotCurve *)active_graph->curve(0);
-		if (cv){
-			d_waterfall_fill_color = cv->brush().color();
-			fillColorBox->setColor(d_waterfall_fill_color);
-			gb1->setChecked(cv->brush().style() != Qt::NoBrush);
-		}
-	}
+	QBrush brush = active_graph->curve(0)->brush();
+	fillColorBox->setColor(brush.style() != Qt::NoBrush ? brush.color() : d_waterfall_fill_color);
+	gb1->setChecked(brush.style() != Qt::NoBrush);
 
-	connect(gb1, SIGNAL(toggled(bool)), this, SLOT(updateWaterfallFill(bool)));
-	connect(fillColorBox, SIGNAL(colorChanged(const QColor&)),
-			this, SLOT(setWaterfallFillColor(const QColor&)));
-	connect(sideLinesBox, SIGNAL(toggled(bool)), this, SLOT(setWaterfallSideLines(bool)));
+	connect(gb1, SIGNAL(toggled(bool)), active_graph, SLOT(updateWaterfallFill(bool)));
+	connect(fillColorBox, SIGNAL(colorChanged(const QColor&)), this, SLOT(setWaterfallFillColor(const QColor&)));
+	connect(sideLinesBox, SIGNAL(toggled(bool)), active_graph, SLOT(setWaterfallSideLines(bool)));
 
 	QPushButton *closeBtn = new QPushButton(tr("&Close"));
 	connect(closeBtn, SIGNAL(clicked()), waterfallFillDialog, SLOT(reject()));
@@ -2133,58 +2012,11 @@ void MultiLayer::showWaterfallFillDialog()
 	waterfallFillDialog->exec();
 }
 
-void MultiLayer::setWaterfallSideLines(bool on)
-{
-	if (d_side_lines == on)
-		return;
-
-	d_side_lines = on;
-
-	QList<Graph*> lst = stackOrderedLayersList();
-	foreach (Graph *g, lst){
-		PlotCurve *cv = (PlotCurve *)g->curve(0);
-		if (cv){
-			cv->enableSideLines(on);
-			g->replot();
-		}
-	}
-	emit modifiedWindow(this);
-}
-
 void MultiLayer::setWaterfallFillColor(const QColor& c)
 {
-	if (d_waterfall_fill_color == c)
-		return;
-
 	d_waterfall_fill_color = c;
-
-	QList<Graph*> lst = stackOrderedLayersList();
-	foreach (Graph *g, lst){
-		QwtPlotCurve *cv = (QwtPlotCurve *)g->curve(0);
-		if (cv){
-			cv->setBrush(QBrush(c));
-			g->replot();
-		}
-	}
-	emit modifiedWindow(this);
-}
-
-void MultiLayer::updateWaterfallFill(bool on)
-{
-	QList<Graph*> lst = stackOrderedLayersList();
-	foreach (Graph *g, lst){
-		PlotCurve *cv = (PlotCurve *)g->curve(0);
-		if (cv){
-			if (on)
-				cv->setBrush(QBrush(d_waterfall_fill_color));
-			else
-				cv->setBrush(QBrush());
-
-			cv->enableSideLines(d_side_lines);
-			g->replot();
-		}
-	}
-	emit modifiedWindow(this);
+	if (active_graph)
+		active_graph->setWaterfallFillColor(c);
 }
 
 void MultiLayer::dragEnterEvent( QDragEnterEvent* e )
@@ -2222,8 +2054,10 @@ void MultiLayer::plotProfiles(Matrix* m)
 
 	double mmin, mmax;
 	m->range(&mmin, &mmax);
-	Graph* g = addLayer();
+	mmin = floor(mmin);
+	mmax = ceil(mmax);
 
+	Graph* g = addLayer();
 	Spectrogram *s = g->plotSpectrogram(m, Graph::GrayScale);
 	if (!s)
 		return;
@@ -2240,7 +2074,7 @@ void MultiLayer::plotProfiles(Matrix* m)
 	g->setAxisTitle(QwtPlot::xTop, QString::null);
 	g->setTitle(QString::null);
 	g->enableAutoscaling(false);
-	g->setCanvasGeometry(QRect(60, 150, 400, 400));
+	g->setCanvasGeometry(QRect(60, 160, 380, 380));
 
 	g = addLayer();
 
@@ -2255,7 +2089,7 @@ void MultiLayer::plotProfiles(Matrix* m)
 	g->setAxisTitle(QwtPlot::xBottom, QString::null);
 	g->setTitle(QString::null);
 	g->enableAutoscaling(false);
-	g->setCanvasGeometry(QRect(60, 0, 400, 100));
+	g->setCanvasGeometry(QRect(60, 10, 380, 100));
 
 	g = addLayer();
 
@@ -2272,7 +2106,7 @@ void MultiLayer::plotProfiles(Matrix* m)
 	g->setAxisTitle(QwtPlot::xTop, QString::null);
 	g->setTitle(QString::null);
 	g->enableAutoscaling(false);
-	g->setCanvasGeometry(QRect(500, 150, 110, 400));
+	g->setCanvasGeometry(QRect(500, 160, 110, 380));
 
 	QColor color = Qt::white;
 	color.setAlpha(0);
