@@ -30,8 +30,11 @@
 #include "ErrorBarsCurve.h"
 #include "BoxCurve.h"
 #include "Graph.h"
+#include "Grid.h"
+#include "MultiLayer.h"
 #include "ScaleDraw.h"
 #include "ScaleEngine.h"
+#include <ApplicationWindow.h>
 #include <SymbolBox.h>
 #include <PatternBox.h>
 #include <ImageSymbol.h>
@@ -43,6 +46,7 @@
 #include <qwt_symbol.h>
 #include <qwt_painter.h>
 #include <qwt_curve_fitter.h>
+#include <qwt_plot_canvas.h>
 
 PlotCurve::PlotCurve(const QString& name): QwtPlotCurve(name),
 d_type(0),
@@ -366,8 +370,8 @@ void PlotCurve::drawSideLines(QPainter *p, const QwtScaleMap &xMap, const QwtSca
 	p->setPen(pen);
 
 	double lw = 0.5*pen.widthF();
-	const double xl = xMap.xTransform(x(from));
-	const double xr = xMap.xTransform(x(to));
+	const double xl = xMap.xTransform(x(from)) - lw;
+	const double xr = xMap.xTransform(x(to)) + lw;
 	const double yl = yMap.xTransform(y(from)) - lw;
 	const double yr = yMap.xTransform(y(to)) - lw;
 	const double base = yMap.xTransform(baseline());
@@ -381,6 +385,7 @@ void PlotCurve::drawSideLines(QPainter *p, const QwtScaleMap &xMap, const QwtSca
 DataCurve::DataCurve(Table *t, const QString& xColName, const QString& name, int startRow, int endRow):
     PlotCurve(name),
 	d_table(t),
+	d_x_table(t),
 	d_x_column(xColName),
 	d_start_row(startRow),
 	d_end_row(endRow),
@@ -399,6 +404,28 @@ DataCurve::DataCurve(Table *t, const QString& xColName, const QString& name, int
 		d_end_row = t->numRows() - 1;
 }
 
+DataCurve::DataCurve(Table *xt, const QString& xColName, Table *yt, const QString& name, int startRow, int endRow):
+	PlotCurve(name),
+	d_table(yt),
+	d_x_table(xt),
+	d_x_column(xColName),
+	d_start_row(startRow),
+	d_end_row(endRow),
+	d_labels_column(QString()),
+	d_labels_color(Qt::black),
+	d_labels_font(QFont()),
+	d_labels_angle(0.0),
+	d_white_out_labels(false),
+	d_show_labels(false),
+	d_labels_align(Qt::AlignHCenter),
+	d_labels_x_offset(0),
+	d_labels_y_offset(50),
+	d_selected_label(NULL)
+{
+	if (yt && d_end_row < 0)
+		d_end_row = yt->numRows() - 1;
+}
+
 void DataCurve::setRowRange(int startRow, int endRow)
 {
 	if (d_start_row == startRow && d_end_row == endRow)
@@ -480,24 +507,40 @@ bool DataCurve::updateData(Table *t, const QString& colName)
 	return true;
 }
 
+void DataCurve::setDataSource(Table *yt, int ycol, Table *xt, int xcol)
+{
+	if (!yt)
+		return;
+
+	d_table = yt;
+	d_x_table = (xt != NULL) ? xt : yt;
+	d_x_column = d_x_table->colName(xcol);
+	setTitle(yt->colName(ycol));
+
+	loadData();
+}
+
 void DataCurve::enableSpeedMode()
 {
 	Graph *g = (Graph *)plot();
 	if (!g)
 		return;
+	if (g->getDouglasPeukerTolerance() == 0.0 || dataSize() < g->speedModeMaxPoints())
+		return;
 
-	if (g->getDouglasPeukerTolerance() != 0.0 && dataSize() >= g->speedModeMaxPoints()){
-		setCurveAttribute(QwtPlotCurve::Fitted);
+	setCurveAttribute(QwtPlotCurve::Fitted);
 
-		QwtWeedingCurveFitter *fitter = new QwtWeedingCurveFitter(g->getDouglasPeukerTolerance());
-		setCurveFitter(fitter);
-	}
-	//g->replot();
+	QwtWeedingCurveFitter *fitter = new QwtWeedingCurveFitter(g->getDouglasPeukerTolerance());
+	setCurveFitter(fitter);
 }
 
 void DataCurve::drawCurve(QPainter *p, int style, const QwtScaleMap &xMap, const QwtScaleMap &yMap, int from, int to) const
 {
-	if (d_data_ranges.empty())
+	Graph *g = (Graph *)plot();
+	if (!g)
+		return;
+
+	if (d_data_ranges.empty() || !g->isMissingDataGapEnabled())
 		return PlotCurve::drawCurve(p, style, xMap, yMap, from, to);
 
 	if(d_side_lines)
@@ -513,7 +556,7 @@ void DataCurve::loadData()
 	if (!g)
 		return;
 
-	int xcol = d_table->colIndex(d_x_column);
+	int xcol = d_x_table->colIndex(d_x_column);
 	int ycol = d_table->colIndex(title().text());
 
 	if (xcol < 0 || ycol < 0){
@@ -523,7 +566,7 @@ void DataCurve::loadData()
 
 	int r = abs(d_end_row - d_start_row) + 1;
     QVarLengthArray<double> X(r), Y(r);
-	int xColType = d_table->columnType(xcol);
+	int xColType = d_x_table->columnType(xcol);
 	int yColType = d_table->columnType(ycol);
 
 	QStringList xLabels, yLabels;// store text labels
@@ -532,58 +575,22 @@ void DataCurve::loadData()
 	if (d_type == Graph::HorizontalBars)
 		xAxis = QwtPlot::yLeft;
 
-	QTime time0;
-	QDateTime date0;
 	QString date_time_fmt = d_table->columnFormat(xcol);
-	if (xColType == Table::Time){
-		ScaleDraw *sd = (ScaleDraw *)g->axisScaleDraw(xAxis);
-		if (sd && sd->scaleType() == ScaleDraw::Time)
-			time0 = sd->dateTimeOrigin().time();
-		else {
-			for (int i = d_start_row; i <= d_end_row; i++ ){
-				QString xval = d_table->text(i, xcol).trimmed();
-				if (!xval.isEmpty()){
-					time0 = QTime::fromString (xval, date_time_fmt);
-					if (time0.isValid())
-						break;
-				}
-			}
-		}
-	} else if (xColType == Table::Date){
-		ScaleDraw *sd = (ScaleDraw *)g->axisScaleDraw(xAxis);
-		if (sd && sd->scaleType() == ScaleDraw::Date)
-			date0 = sd->dateTimeOrigin();
-		else {
-			for (int i = d_start_row; i <= d_end_row; i++ ){
-				QString xval = d_table->text(i, xcol).trimmed();
-				if (!xval.isEmpty()){
-					date0 = QDateTime::fromString (xval, date_time_fmt);
-					if (date0.isValid())
-						break;
-				}
-			}
-		}
-	}
-
 	int size = 0, from = 0;
 	d_data_ranges.clear();
 	for (int i = d_start_row; i <= d_end_row; i++ ){
-		QString xval = d_table->text(i, xcol);
+		QString xval = d_x_table->text(i, xcol);
 		QString yval = d_table->text(i, ycol);
 		if (!xval.isEmpty() && !yval.isEmpty()){
 			bool valid_data = true;
 			if (xColType == Table::Text){
 				xLabels << xval;
 				X[size] = (double)(size + 1);
-			} else if (xColType == Table::Time){
-				QTime time = QTime::fromString(xval.trimmed(), date_time_fmt);
-				if (time.isValid())
-					X[size]= time0.msecsTo (time);
-			} else if (xColType == Table::Date){
-				QDateTime d = QDateTime::fromString(xval.trimmed(), date_time_fmt);
-				if (d.isValid())
-					X[size] = (double) date0.secsTo(d);
-			} else
+			} else if (xColType == Table::Time)
+				X[size] = Table::fromTime(QTime::fromString(xval.trimmed(), date_time_fmt));
+			  else if (xColType == Table::Date)
+				X[size] = Table::fromDateTime(QDateTime::fromString(xval.trimmed(), date_time_fmt));
+			  else
 				X[size] = g->locale().toDouble(xval, &valid_data);
 
 			if (yColType == Table::Text){
@@ -613,6 +620,34 @@ void DataCurve::loadData()
 	X.resize(size);
 	Y.resize(size);
 
+	if (g->isWaterfallPlot()){
+		int index = g->curveIndex(this);
+		int curves = g->curveCount();
+		DataCurve *c = g->dataCurve(0);
+		if (index > 0 && c){
+			double xmin = c->minXValue();
+			double dx = index*g->waterfallXOffset()*0.01*g->canvas()->width()/(double)(curves - 1);
+			d_x_offset = g->invTransform(xAxis, g->transform(xAxis, xmin) + dx) - xmin;
+
+			double ymin = c->minYValue();
+			double dy = index*g->waterfallYOffset()*0.01*g->canvas()->height()/(double)(curves - 1);
+			d_y_offset = ymin - g->invTransform(yAxis(), g->transform(yAxis(), ymin) + dy);
+			
+			setZ(-index);
+			setBaseline(d_y_offset);
+
+			for (int i = 0; i < size; i++){
+				X[i] = X[i] + d_x_offset;
+				Y[i] = Y[i] + d_y_offset;
+			}
+		} else {
+			setZ(0);
+			setBaseline(0.0);
+		}
+		if (g->grid())
+			g->grid()->setZ(-g->curveCount() - 1);
+	}
+
 	if (!size){
 		remove();
 		return;
@@ -682,8 +717,8 @@ void DataCurve::setVisible(bool on)
 
 int DataCurve::tableRow(int point)
 {
-    if (!d_table)
-        return -1;
+	if (!d_table)
+		return -1;
 
 	if (d_type == Graph::Pie){
 		double y_val = y(point);
@@ -700,38 +735,38 @@ int DataCurve::tableRow(int point)
 	if (xcol < 0 || ycol < 0)
 		return -1;
 
-    int xColType = d_table->columnType(xcol);
-    if (xColType == Table::Date){
-        QString format = d_table->columnFormat(xcol);
-        QDate date0 = QDate::fromString (d_table->text(d_start_row, xcol), format);
-        for (int i = d_start_row; i <= d_end_row; i++ ){
-            QDate d = QDate::fromString (d_table->text(i, xcol), format);
-            if (d.isValid()){
-                if (d_type == Graph::HorizontalBars && date0.daysTo(d) == y(point) && d_table->cell(i, ycol) == x(point))
-                    return i;
-                else if (date0.daysTo(d) == x(point) && d_table->cell(i, ycol) == y(point))
-                    return i;
-            }
-        }
-    } else if (xColType == Table::Time){
-        QString format = d_table->columnFormat(xcol);
-        QTime t0 = QTime::fromString (d_table->text(d_start_row, xcol), format);
-        for (int i = d_start_row; i <= d_end_row; i++ ){
-            QTime t = QTime::fromString (d_table->text(i, xcol), format);
-            if (t.isValid()){
-                if (d_type == Graph::HorizontalBars && t0.msecsTo(t) == y(point) && d_table->cell(i, ycol) == x(point))
-                    return i;
-                if (t0.msecsTo(t) == x(point) && d_table->cell(i, ycol) == y(point))
-                    return i;
-            }
-        }
-    } else if (xColType == Table::Text){
+	int xColType = d_table->columnType(xcol);
+	if (xColType == Table::Date){
+		QString format = d_table->columnFormat(xcol);
+		QDateTime date0 = QDateTime::fromString (d_table->text(d_start_row, xcol), format);
+		for (int i = d_start_row; i <= d_end_row; i++ ){
+			QDateTime d = QDateTime::fromString (d_table->text(i, xcol), format);
+			if (d.isValid()){
+				if (d_type == Graph::HorizontalBars && date0.secsTo(d) == y(point) && d_table->cell(i, ycol) == x(point))
+					return i;
+				else if (date0.secsTo(d) == x(point) && d_table->cell(i, ycol) == y(point))
+					return i;
+			}
+		}
+	} else if (xColType == Table::Time){
+		QString format = d_table->columnFormat(xcol);
+		QTime t0 = QTime::fromString (d_table->text(d_start_row, xcol), format);
+		for (int i = d_start_row; i <= d_end_row; i++ ){
+			QTime t = QTime::fromString (d_table->text(i, xcol), format);
+			if (t.isValid()){
+				if (d_type == Graph::HorizontalBars && t0.msecsTo(t) == y(point) && d_table->cell(i, ycol) == x(point))
+					return i;
+				if (t0.msecsTo(t) == x(point) && d_table->cell(i, ycol) == y(point))
+					return i;
+			}
+		}
+	} else if (xColType == Table::Text){
 		double y_val = y(point);
-        for (int i = d_start_row; i <= d_end_row; i++ ){
+		for (int i = d_start_row; i <= d_end_row; i++ ){
 			if (d_table->cell(i, ycol) == y_val)
 				return i;
-        }
-    }
+		}
+	}
 
 	double x_val = x(point);
 	double y_val = y(point);
@@ -752,7 +787,7 @@ void DataCurve::setLabelsColumnName(const QString& name)
 		return;
 
 	d_labels_column = name;
-    loadLabels();
+	loadLabels();
 }
 
 void DataCurve::loadLabels()
