@@ -39,7 +39,7 @@ public:
 	enum BarStyle{Vertical = 0, Horizontal = 1};
 	QwtBarCurve(BarStyle style, Table *t, const QString& xColName, const QString& name, int startRow, int endRow);
 
-	void copy(const QwtBarCurve *b);
+	void copy(QwtBarCurve *b);
 
 	virtual QwtDoubleRect boundingRect() const;
 
@@ -58,13 +58,13 @@ public:
 
 	virtual QString saveToString();
 
+	QList <QwtBarCurve *> stackedCurvesList() const;
+	double stackOffset(int i, QList <QwtBarCurve *> stack) const;
+
 private:
 	virtual void draw(QPainter *painter,const QwtScaleMap &xMap,
 		const QwtScaleMap &yMap, int from, int to) const;
 
-	QList <QwtBarCurve *> stackedCurvesList() const;
-	double stackOffset(int i, QList <QwtBarCurve *> stack) const;
-
 protected:
 	int bar_offset;
 	int bar_gap;
