@@ -2,7 +2,7 @@
     File                 : ScaleDraw.cpp
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief
+	Copyright            : (C) 2006 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Extension to QwtScaleDraw
 
@@ -31,6 +31,7 @@
 #include "MultiLayer.h"
 #include <MyParser.h>
 #include "ScaleEngine.h"
+#include "Table.h"
 
 #include <QDateTime>
 #include <QPainter>
@@ -51,13 +52,12 @@ ScaleDraw::ScaleDraw(Graph *plot, const QString& formula):
 	d_type(Numeric),
 	d_numeric_format(Automatic),
 	d_fmt('g'),
-	d_prec(4),
+	d_prec(6),
 	d_formula(formula),
 	d_majTicks(Out),
 	d_minTicks(Out),
 	d_selected(false),
 	d_name_format(ShortName),
-	d_date_time_origin(QDateTime::currentDateTime()),
 	d_format_info("YYYY-MM-DDTHH:MM:SS"),
 	d_text_labels(QStringList()),
 	d_show_ticks_policy(ShowAll),
@@ -70,13 +70,12 @@ ScaleDraw::ScaleDraw(Graph *plot, const QStringList& labels, const QString& form
 	d_type(type),
 	d_numeric_format(Automatic),
 	d_fmt('g'),
-	d_prec(4),
+	d_prec(6),
 	d_formula(""),
 	d_majTicks(Out),
 	d_minTicks(Out),
 	d_selected(false),
 	d_name_format(ShortName),
-	d_date_time_origin(QDateTime::currentDateTime()),
 	d_format_info(format),
 	d_text_labels(labels),
 	d_prefix(""),
@@ -95,7 +94,6 @@ ScaleDraw::ScaleDraw(Graph *plot, ScaleDraw* sd):
 	d_minTicks = sd->d_minTicks;
 	d_selected = sd->d_selected;
 	d_name_format = sd->d_name_format;
-	d_date_time_origin = sd->d_date_time_origin;
 	d_format_info = sd->d_format_info;
 	d_text_labels = sd->d_text_labels;
 	d_show_ticks_policy = sd->showTicksPolicy();
@@ -112,6 +110,7 @@ QwtText ScaleDraw::label(double value) const
 	if (s.isEmpty())
 		return QwtText();
 
+	s.replace("-", QChar(0x2212));
 	return QwtText(d_prefix + s + d_suffix);
 }
 
@@ -259,7 +258,7 @@ QString ScaleDraw::labelString(double value) const
 
 		case Time:
 		{
-			QTime time = d_date_time_origin.time().addMSecs((int)value);
+			QTime time = Table::dateTime(value).time();
 			if (d_format_info == "M")
 				return QString::number(60*time.hour() + time.minute());
 			else if (d_format_info == "S")
@@ -270,7 +269,7 @@ QString ScaleDraw::labelString(double value) const
 		}
 
 		case Date:
-			return d_date_time_origin.addSecs((int)value).toString(d_format_info);
+			return Table::dateTime(value).toString(d_format_info);
 		break;
 
 		case ColHeader:
@@ -343,17 +342,12 @@ QString ScaleDraw::labelString(double value) const
 
 void ScaleDraw::drawLabel(QPainter *painter, double value) const
 {
-    if (!d_plot)
-        return;
+	if (!d_plot)
+		return;
 
-    ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
-	if (sc_engine->hasBreak()){
-		bool invertedScale = sc_engine->testAttribute(QwtScaleEngine::Inverted);
-		if (invertedScale && (sc_engine->axisBreakLeft() > value && sc_engine->axisBreakRight() < value))
-        	return;
-		if (!invertedScale && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
-        	return;
-	}
+	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
+	if (sc_engine->hasBreak() && sc_engine->axisBreakLeft() <= value && sc_engine->axisBreakRight() > value)
+		return;
 
 	QwtValueList majTicks = scaleDiv().ticks(QwtScaleDiv::MajorTick);
 	if (majTicks.contains(value)){
@@ -377,36 +371,36 @@ void ScaleDraw::drawLabel(QPainter *painter, double value) const
 	}
 
 	QwtText lbl = tickLabel(painter->font(), value);
-    if ( lbl.isEmpty() )
-        return;
+	if ( lbl.isEmpty() )
+		return;
 
-    QPoint pos = labelPosition(value);
+	QPoint pos = labelPosition(value);
 
-    QSize labelSize = lbl.textSize(painter->font());
-    if ( labelSize.height() % 2 )
-        labelSize.setHeight(labelSize.height() + 1);
+	QSize labelSize = lbl.textSize(painter->font());
+	if ( labelSize.height() % 2 )
+		labelSize.setHeight(labelSize.height() + 1);
 
-    const QwtMetricsMap metricsMap = QwtPainter::metricsMap();
-    QwtPainter::resetMetricsMap();
+	const QwtMetricsMap metricsMap = QwtPainter::metricsMap();
+	QwtPainter::resetMetricsMap();
 
-    labelSize = metricsMap.layoutToDevice(labelSize);
-    pos = metricsMap.layoutToDevice(pos);
+	labelSize = metricsMap.layoutToDevice(labelSize);
+	pos = metricsMap.layoutToDevice(pos);
 
-    painter->save();
-    painter->setMatrix(labelMatrix( pos, labelSize), true);
+	painter->save();
+	painter->setMatrix(labelMatrix( pos, labelSize), true);
 
 	if (d_selected)
-        lbl.setBackgroundPen(QPen(Qt::blue));
-    else
-        lbl.setBackgroundPen(QPen(Qt::NoPen));
+		lbl.setBackgroundPen(QPen(Qt::blue));
+	else
+		lbl.setBackgroundPen(QPen(Qt::NoPen));
 
 	lbl.setRenderFlags(labelAlignment());
 
-    lbl.draw (painter, QRect(QPoint(0, 0), labelSize) );
+	lbl.draw (painter, QRect(QPoint(0, 0), labelSize) );
 
-    QwtPainter::setMetricsMap(metricsMap); // restore metrics map
+	QwtPainter::setMetricsMap(metricsMap); // restore metrics map
 
-    painter->restore();
+	painter->restore();
 }
 
 double ScaleDraw::transformValue(double value) const
@@ -500,9 +494,24 @@ int ScaleDraw::axis() const
 
 void ScaleDraw::drawTick(QPainter *p, double value, int len) const
 {
-	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
-	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
-		return;
+	int axis = this->axis();
+	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis);
+	if (sc_engine->hasBreak()){
+		double dlb = sc_engine->axisBreakLeft();
+		double drb = sc_engine->axisBreakRight();
+		if ((dlb < value && drb > value) ||
+			((axis == QwtPlot::yLeft || axis == QwtPlot::xBottom) && value == dlb) ||
+			((axis == QwtPlot::yRight || axis == QwtPlot::xTop) && value == drb) ||
+			(sc_engine->testAttribute(QwtScaleEngine::Inverted) && (value == dlb || value == drb)))
+			return;
+
+		if (d_plot->isPrinting()){
+			QwtScaleMap scaleMap = map();
+			double val = scaleMap.transform(value);
+			if (val >= scaleMap.transform(dlb) && val <= scaleMap.transform(drb))
+				return;
+		}
+	}
 
 	QwtScaleDiv scDiv = scaleDiv();
 	QwtValueList majTicks = scDiv.ticks(QwtScaleDiv::MajorTick);
@@ -537,13 +546,13 @@ void ScaleDraw::drawTick(QPainter *p, double value, int len) const
     if (minTicks.contains(value) && (d_minTicks == In || d_minTicks == None))
         return;
 
-    QwtScaleDraw::drawTick(p, value, len);
+	QwtScaleDraw::drawTick(p, value, len);
 }
 
 void ScaleDraw::drawInwardTick(QPainter *painter, double value, int len) const
 {
 	ScaleEngine *sc_engine = (ScaleEngine *)d_plot->axisScaleEngine(axis());
-	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() < value && sc_engine->axisBreakRight() > value))
+	if (sc_engine->hasBreak() && (sc_engine->axisBreakLeft() <= value && sc_engine->axisBreakRight() >= value))
 		return;
 
 	int pw2 = qwtMin((int)painter->pen().width(), len) / 2;
@@ -813,28 +822,14 @@ void ScaleDraw::setMonthFormat(NameFormat format)
 	d_name_format = format;
 }
 
-void ScaleDraw::setTimeFormat(const QString& format, const QTime& t)
+void ScaleDraw::setTimeFormat(const QString& format)
 {
 	d_type = Time;
 	d_format_info = format;
-	if (!t.isNull() && t.isValid())
-		d_date_time_origin.setTime(t);
 }
 
-void ScaleDraw::setDateFormat(const QString& format, const QDateTime& d)
+void ScaleDraw::setDateFormat(const QString& format)
 {
 	d_type = Date;
 	d_format_info = format;
-	if (!d.isNull() && d.isValid())
-		d_date_time_origin = d;
-}
-
-QString ScaleDraw::formatString()
-{
-	if (d_type == Time)
-		return d_date_time_origin.time().toString() + ";" + d_format_info;
-	else if (d_type == Date)
-		return d_date_time_origin.toString(d_format_info) + ";" + d_format_info;
-
-	return d_format_info;
 }
