@@ -2,7 +2,7 @@
     File                 : PlotDialog.h
     Project              : QtiPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2006 by Ion Vasilief
+	Copyright            : (C) 2006 - 2011 by Ion Vasilief
     Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Custom curves dialog
 
@@ -119,7 +119,6 @@ private slots:
 	void enableBoxApplyColor(int);
 
 	void setAutomaticBinning(bool on = true);
-	void showPlotAssociations(QTreeWidgetItem *item, int);
 
 	//box plots
 	void setBoxType(int index);
@@ -144,6 +143,8 @@ private slots:
 
     void setActiveLayer(LayerItem *item);
     void updateTreeWidgetItem(QTreeWidgetItem *item);
+	void updateVisibility();
+	void updateVisibility(QTreeWidgetItem *item, int column);
     void updateBackgroundTransparency(int alpha);
     void updateCanvasTransparency(int alpha);
 	void setTitlesFont();
@@ -151,6 +152,7 @@ private slots:
 	void setAxesNumbersFont();
 	void setLegendsFont();
 	void editCurve();
+	void editCurveRange();
 	void chooseLabelsFont();
 	void applyLayerFormat();
 	void applyCanvasFormat();
@@ -214,6 +216,7 @@ private:
 	void initCanvasPage();
 	void initLayerGeometryPage();
 	void initPlotGeometryPage();
+	void initLayerDisplayPage();
 	void initLayerSpeedPage();
 	void initFontsPage();
 	void initMiscPage();
@@ -240,9 +243,10 @@ private:
 
     QPushButton *btnTitle, *btnAxesLabels, *btnAxesNumbers, *btnLegend;
 	ColorMapEditor *colorMapEditor;
-	QWidget *curvePlotTypeBox, *layerPage, *layerGeometryPage, *piePage, *fontsPage, *printPage, *speedPage, *functionPage, *canvasPage;
+	QWidget *curvePlotTypeBox, *layerPage, *layerGeometryPage, *piePage, *fontsPage, *printPage;
+	QWidget *layerDisplayPage, *speedPage, *functionPage, *canvasPage;
     QTreeWidget* listBox;
-	QCheckBox *boxAntialiasing, *boxScaleLayers, *boxPrintCrops, *boxAutoscaling;
+	QCheckBox *boxAntialiasing, *boxScaleLayers, *boxPrintCrops, *boxAutoscaling, *boxGridPosition, *boxMissingData;
     ColorButton *boxBorderColor, *boxBackgroundColor, *boxCanvasColor;
 	QSpinBox *boxBackgroundTransparency, *boxCanvasTransparency, *boxBorderWidth, *boxMargin;
 	QSpinBox *boxRadius;
@@ -285,7 +289,7 @@ private:
 	QWidget *histogramPage, *spacingPage;
 	DoubleSpinBox *binSizeBox, *histogramBeginBox, *histogramEndBox;
 	QCheckBox *automaticBox;
-	QPushButton* buttonStatistics, *btnEditCurve, *buttonBoxStatistics;
+	QPushButton* buttonStatistics, *btnEditCurve, *buttonBoxStatistics, *btnEditCurveRange;
 	QSpinBox* gapBox, *offsetBox, *boxWidth;
 	QWidget *vectPage, *boxPage, *percentilePage, *axesPage;
 	QComboBox *xEndBox, *yEndBox, *boxType, *boxWhiskersType, *boxWhiskersRange, *boxRange;
@@ -353,8 +357,8 @@ private:
 	QComboBox *boxLinkAllXAxes;
 
 	FunctionDialog *functionEdit;
-	QSpinBox *boxCurveOpacity;
-	QSlider *curveOpacitySlider;
+	QSpinBox *boxCurveOpacity, *boxSymbolTransparency, *boxLineTransparency, *boxPercentileTransparency;
+	QSlider *curveOpacitySlider, *symbTransparencySlider, *lineTransparencySlider, *percentileTransparencySlider;
 
 	DoubleSpinBox *boxPlotX, *boxPlotY, *boxPlotWidth, *boxPlotHeight;
 	QComboBox *plotUnitBox, *gapApplyToBox;
@@ -372,8 +376,9 @@ private:
 	ColorButton *boxFrameColor;
 	QSpinBox *boxFrameWidth;
 	QPushButton *canvasDefaultBtn;
-	QSlider *canvasOpacitySlider;
+	QSlider *canvasOpacitySlider, *bkgOpacitySlider;
 
+	QCheckBox *boxLeftAxis, *boxRightAxis, *boxBottomAxis, *boxTopAxis;
 	QCompleter *completer;
 };
 
